#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoX+XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXoXXXoXoXoXoXoXoXoXoXXXoXoXOXOX+X+X+X+X+X+XOXOXoXoXXXoXoXoXoXoXoXoXXXOX.X].+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X]..XOXXXoXoXoXoXoXoXoXoXoXoXoXOXOX+X+X+X+X+X+XOXOXoXoXXXoXoXoXoXoXoXoXXXoX+X+XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX6XyXtXtXtXtXtXtXtXyXpXuX=XC.&.W G C C G W *.C.=XuXpXyXtXtXtXtXtXtXyX2XOXL.A B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B A L.OX2XyXtXtXtXtXtXtXtXyXpXiX<XH.>.! H Z C F T +.b.#XtXaXyXtXtXtXtXtXtXyX6XoXOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXXXyXcXzXzXzXzXzXxXmXpXQ.3.] N 7 %         % 8 N ] 4.Q.pXmXxXzXzXzXzXcX0X@XA.                                                                    A.@X0XcXzXzXzXzXzXxXmXfX].8.| A q &         # 4 b ( <.K.rXmXcXzXzXzXzXcXyXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXlXlXzXdX`.r.D #   7 F )  .+.+. .) D 7   # D e.`.fXzXlXlXlXxX9X@XA.+                                                                 + A.@X9XxXlXlXlXlXxXgX.Xs.T *   3 C / | +.@...` J w   o b 6.W.pXzXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXzXlXwXD.H & > b / w.^.:XeXkXkXeX:X~.q./ v : % H G.wXlXzXlXxX9X@XA.+                                                                 + A.@X9XxXlXlXlXzXyXT.! ; * z W 5.T.=XqXhXlXtX<X_.i.' M 2 @ n m.6XkXzXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXzXjX6Xx.e * r [ ~.jXxXzXzXlXlXlXlXzXzXxXjXQ.] r * r c.6XjXzXxX9X@XA.+                                                                 + A.@X9XxXlXlXkXqXA.k $ 0 Q L.dXzXzXzXlXlXlXlXzXzXxXlX{.#.i ; 3 i.,XhXzXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlX6X0.5 : V G.aXjXlXlXlXlXlXlXlXlXlXlXlXlXjXaXF.C , 5 0.6XlXxX9X@XA.+                                                                 + A.@X9XxXlXlXrXf.t = c l.iXjXlXlXlXlXlXlXlXlXlXlXlXlXkXdX~.L 3 > -.;XzXxXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXzXwXx.5 : ' }.gXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX}.` : 5 c.wXcX9X@XA.+                                                                 + A.@X9XxXzXuXH.t * T Q.fXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX&X@.2 > w.6XcXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXdXD.e , ' oXhXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhXoX` > r G.gX0X@XA.+                                                                 + A.@X9XxXgX/.f - T (.fXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXjX;X@.3 6 g.sXyXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXmX_.G * Z |.hXxXlXlXlXlXlXxXvXnXmXmXnXvXxXlXlXlXlXlXxXhX}.V * J ].tX+XA.+                                                                 + A.@X9XmX%XQ = z W.dXxXlXlXlXlXlXlXlXxXnXmXmXmXxXlXlXlXlXlXzXkX&XY = m P.aXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXyXaXr.% r F.gXzXlXlXlXlXzXzX>XS.0.-.;.w.J.6XzXzXlXlXlXlXzXgXF.r & t.,X@XA.+                                                                 + A.@X0XfXN.> 1 c.iXcXlXlXlXlXlXlXzXbX&Xd.@.#.>.XXdXzXlXlXlXlXlXzXQ.x @ &.<XoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXXXpX!.D : [ aXlXlXlXlXlXxXsXQ.+.j &     - v :.XXfXzXlXlXlXlXlXaX[ : G V.&XA.+                                                                 + A.@XrX.XQ ; I 9XzXlXlXlXlXlXlXlXsX~...5     # V.uXzXlXlXlXlXlXlXkX>.1 v z.OXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXuX3.@ v !.jXlXlXlXlXzXhX}.S .   , y r -   O [ >XzXlXlXlXlXlXjXQ.v % o.$XA.+                                                                 + A.@XeXx.* y J.dXzXlXlXlXlXlXlXaXD.B o   o   : A.uXzXlXlXlXlXlXlXzX{.L # E .XoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX-X'   / jXlXlXlXlXlXcX3X1..   8 O.n.l.^ =   $ G.aXzXlXlXlXlXlXhX^   I (.S.+                                                                 + A.#X-X2.  B uXlXlXlXlXlXlXlXjX3Xg   2 r <   : A.uXzXlXlXlXlXlXlXlXxX:.. v U.XXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXV.N 7 w.xXlXlXlXlXlXvX@XQ 2 4 f.7XkXzXXXU X O 7.5XcXlXlXlXlXlXxX0.7 j k.S.+                                                                 + A.%XH.U 1 &.fXlXlXlXlXlXlXlXjX;Xg 5 q.h.k   : A.uXzXlXlXlXlXlXlXlXbXc.y t q..XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOX&.7 F ^.zXlXlXlXlXlXzXiX$X{.}.qXjXlXcX&X] o + w.7XxXlXlXlXlXlXzX!.D 2 @.D.+                                                                 + A.*X8.r z K.jXlXlXlXlXlXlXlXjX,X .F.sXI.k   : A.uXzXlXlXlXlXlXlXlXcX|.~ , ! |.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XW % ) >XzXlXlXlXlXlXlXkXhXgXgXkXxXjX<Xy.7 . 2 Q.gXzXlXlXlXlXlXzX;X( # Q D.+                                                                 + A.=X+.& D #XkXlXlXlXlXlXlXlXkXaX3XiXnXY.k   : A.uXzXlXlXlXlXlXlXlXxX4X=.$ M }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XF    .rXlXlXlXlXlXlXlXlXzXzXlX7X,.G V e - C c.qXzXlXlXlXlXlXlXlXeX .  K D.+                                                                 + A.=X'   L 7XkXlXlXlXlXlXlXlXlXlXcXzXnXU.k   : A.uXzXlXlXlXlXlXlXlXzXiX7.. g }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XC   +.kXlXlXlXlXlXlXlXlXlXlXkX;Xl       : Q |.hXxXlXlXlXlXlXlXlXkX+.  F D.+                                                                 + A.-X(   I sXlXlXlXlXlXlXlXlXlXlXlXlXnXU.k   : A.uXzXlXlXlXlXlXlXlXlXzXy.  p }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XC   +.kXlXlXlXlXlXlXlXlXlXlXkX8X5.T H y $ p | }.dXzXlXlXlXlXlXlXjX+.  F D.+                                                                 + A.-X(   P sXlXlXlXlXlXlXlXlXlXlXlXlXnXU.k   : A.uXzXlXlXlXlXlXlXlXlXzXy.  p }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XF    .eXlXlXlXlXlXlXlXzXxXxXxXjX8X,X Xt.d     O.:XcXlXlXlXlXlXlXwX .  K D.+                                                                 + A.=X'   K 6XkXlXlXlXlXlXlXlXlXlXlXlXnXU.k   : A.uXzXlXlXlXlXlXlXlXzXuX7.. g }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XW % ) :XzXlXlXlXlXlXlXfX0X0XqXhXzXzXcXqXp.O . 9 ^.nXlXlXlXlXlXzX-X( # Q D.+                                                                 + A.=X+.* D @XkXlXlXlXlXlXlXlXlXlXlXlXnXU.k   : A.uXzXlXlXlXlXlXlXlXxX3X*.$ M }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOX*.8 F ^.zXlXlXlXlXlXcX-Xq.0.r.3XlXlXzXaXD.+   % T.mXlXlXlXlXlXzXQ.S 2 #.D.+                                                                 + A.*X9.t z K.jXlXlXlXlXlXlXlXlXlXlXlXnXU.k   : A.uXzXlXlXlXlXlXlXlXcX}.! , ! |.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXC.N 7 q.xXlXlXlXlXlXnX^.q = > j.9XjXlX-X@.o . 0 /.nXlXlXlXlXlXxX8.6 k l.S.+                                                                 + A.%XK.Y 1 %.fXlXlXlXlXlXlXlXlXlXlXlXnXU.k   : A.uXzXlXlXlXlXlXlXlXbXx.r t e..XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX-X]   / jXlXlXlXlXlXvX#XE .   8 ] s.i.~ >   X { =XvXlXlXlXlXlXhX^   I (.S.+                                                                 + A.#X-X2.  B uXlXlXlXlXlXlXlXlXlXlXlXnXU.k   : A.uXzXlXlXlXlXlXlXlXxX:.  b Y.XXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXuX4.# v Q.jXlXlXlXlXzXaXT.h     - q 0 *     m /.dXzXlXlXlXlXjXW.c & o.$XA.+                                                                 + A.@XeXc.= y G.dXzXlXlXlXlXlXlXlXlXlXnXU.k   : A.uXzXlXlXlXlXlXlXzX[.K # E .XoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXXXpX!.F : ] pXlXlXlXlXlXxXuXH.] a $     = j o.Y.pXxXlXlXlXlXlXpX` : G C.&XA.+                                                                 + A.@XrXXX! - P 8XzXlXlXlXlXlXlXlXlXlXnXP.a   # V.uXzXlXlXlXlXlXlXjX;.< v x.OXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXyXaXt.% r D.gXzXlXlXlXlXxXzX$XM.8.-.;.q.A.:XxXzXlXlXlXlXzXfXA.e * y.,X@XA.+                                                                 + A.@X0XfXB., 1 x.uXcXlXlXlXlXlXlXlXlXcX$Xt.@.>.XXdXzXlXlXlXlXlXlXR.l @ &.<XoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXmX`.H * V }.hXxXlXlXlXlXlXxXbXnXmXmXnXvXxXlXlXlXlXlXxXhX[.N & K [.tX+XA.+                                                                 + A.@X9XnX%X~ = k E.dXxXlXlXlXlXlXlXlXlXxXnXmXmXxXlXlXlXlXlXzXkX%XI * M I.aXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXfXG.r > ` oXhXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhXXX) > t H.gX0X@XA.+                                                                 + A.@X9XxXgX).g - Y /.fXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXjX;XO.3 7 h.dXyXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXzXwXc.5 : _ }.gXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfX{.) ; 5 b.eXcX9X@XA.+                                                                 + A.@X9XxXzXuXH.t * U W.dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX%XO.2 > r.7XcXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlX6X0.5 > B D.pXjXlXlXlXlXlXlXlXlXlXlXlXlXjXpXS.B , 5 q.6XlXxX9X@XA.+                                                                 + A.@X9XxXlXlXrXf.t - x j.yXjXlXlXlXlXlXlXlXlXlXlXlXlXkXsXQ.H 2 > :.;XzXxXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXzXjX6Xc.r & e ' Q.hXxXzXzXlXlXlXlXzXzXxXhXW.' e * t b.6XjXzXxX9X@XA.+                                                                 + A.@X9XxXlXlXkXqXS.l $ 9 E H.sXzXzXzXlXlXlXlXzXzXxXlX[.@.u ; 4 a.,XhXzXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXzXlXwXG.J & : v ~ 9.!.;XeXkXkXeX;X!.9.~ c ; & K G.eXlXzXlXxX9X@XA.+                                                                 + A.@X9XxXlXlXlXzXuXR.^ : & l R 3.Y.*XqXhXlXtX>X).y._ m 1 @ M m.7XkXzXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXXXyXcXxXxXxXxXcXgX].y.G %   7 D (  .+.+. .( S 7   % G y.].gXcXxXxXxXcX0X@XZ.                                                                    Z.@X0XcXxXxXxXxXcXkXOXf.E ;   2 V ^ | +.@..._ H w . + M 9.~.sXcXxXxXxXcXyXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX2X0X9X9X9X9X9X0XtX,XC.o.I k 2 #         # 2 k U o.C.<XtX0X9X9X9X9X0X,XoXU._ / / / / / / / / / / / / / / / / / / / / / / / / / / / / / / / / _ U.oX,X0X9X9X9X9X9X0XtX4XL.$.R x 5 $         + , f K | x.-XtXqX0X9X9X9X0X2XOXOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XXX.X.X.X.X.X.X.X.XXX+XOX!.h.+.W J D D J W +.h.~.OX+XXX.X.X.X.X.X.X.XoXXX{.$X$X$X$X$X$X$X$X$X$X$X$X%X*X=X=X-X-X-X=X=X*X%X$X$X$X$X$X$X$X$X$X$X$X{.XXoX.X.X.X.X.X.X.X.X.XOX+X(.l.#.R F V B S I } i.R.oX+XXX.X.X.X.X.X.X.XXX+X+XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOX%X*X*X*X*X*X*X*X*X*X=X=X@X'.R.K.G.F.F.G.K.R.'.@X=X=X*X*X*X*X*X*X*X*X$XOX@X*X*X*X*X*X*X*X*X*X*X-X&X.X^.P.G.D.A.S.F.L.!.|.%X=X=X*X*X*X*X*X*X*X*X@XOX$X*X*X*X*X*X*X*X*X*X*X*X*X=X=X-X-X-X-X-X-X-X=X*X*X*X*X*X*X*X*X*X*X*X%X+XOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXrXlXkXkXkXkXkXkXkXgXuX3X).9.D w : # # : w D 9.).3XuXgXkXkXkXkXkXkXlX9X.X*XjXkXkXkXkXkXkXkXkXdXwX=XS...k 4 = @ & 2 f ` n.$X0XsXjXkXkXkXkXkXkXjX*X.X9XlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXrXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXlXlXlXkXjX:Xq.j 6 1 2 1 > * * > 1 2 1 6 j q.;XjXkXlXlXlXlXxX9X.X*XkXlXlXlXlXlXlXkXpX/.! r 3 1 2 < ; % - < 2 1 2 w K I.rXkXlXlXlXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXlXlXlX9Xe.V 8 $ = V 5.N.T.].].T.N.4.B = $ 7 B e.0XlXlXlXlXxX9X.X*XkXlXlXlXlXzXfX|.' h , O 0 ( d.G.~.}./.K.j.} y O : p W !.dXzXlXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXzXkX#X} w o y >.I.|.4XyXfXzXzXfXyX3X|.I.:.t o w | $XkXzXlXxX9X.X*XkXlXlXlXcXuXS.B > + L j.^.%X0XpXhXxXjXaXwX=X).n.Q $ = x l.wXcXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXxXdX(.( - 2 ` D.1XvXbXcXxXzXlXlXzXxXcXbXvX<XS.` 2 ; ) (.dXxXzX9X.X*XkXlXlXcX6Xj.x + g 0._.iXnXvXxXzXzXlXzXzXxXvXnXfX{.p.b $ s w.>XxXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXzXhX XR $ a <.%XvXcXlXlXlXlXlXlXlXlXlXlXlXlXcXvX$X<.s $ R  XhXcX9X.X*XkXlXzXuXj.a & H m.pXvXzXlXlXlXlXlXlXlXlXlXlXlXzXvXgXH.W > 9 9.wXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXlX%Xo.& p i.9XbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbX9Xu.p & O.&XxX0X.X*XkXlXfXS.c & I R.xXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXbX'._ : u x.pXjX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXvX7X9.$ w y.wXxXlXlXlXlXlXlXlXlXzXxXxXxXxXlXlXlXlXlXxXwXt.q $ q.0XwX.X*XkXkX|.B @ J R.xXlXlXlXlXlXlXlXlXzXxXxXxXzXlXlXlXlXlXlXvX].^ % s /.dX=X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXzXzXxXxXxXxXzXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXbXZ.r 2 | qXzXlXlXlXlXlXlXlXlXhXrX6X7X8XeXjXlXlXlXlXlXzXqX} 1 y D.eX.X*XkXpX_ > g m.xXlXlXlXlXlXlXlXlXjXyX8X7X7XtXhXlXlXlXlXlXlXcXY.b : P 6X=X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXdXtX0X8X8XqXuXhXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXuX3X&.O x :XjXlXlXlXlXlXlXlXlXzX:X[ > 2 9 Q eXxXlXlXlXlXlXjX:Xc + *. XoX*XdX(.g O 9.iXzXlXlXlXlXlXlXlXjX>X-.w 2 > =.<XxXlXlXlXlXlXzXdXn.* 0 J.XXXX9XxXlXlXlXlXlXlXlXlXlXlXlXsXI. .z w t S 8.;XfXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXaXz.r r r.fXlXlXlXlXlXlXlXlXlXzX7.5     + A qXxXlXlXlXlXlXlXfXe.r y 0.@X-XwX! , K ).vXlXlXlXlXlXlXzXaXY.G ,       } :XxXlXlXlXlXlXlXcX#X^ , G T.OX9XxXlXlXlXlXlXlXlXlXlXzXuX5.d = o     @ 2 m ^.dXzXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXqX&.  D <XkXlXlXlXlXlXlXlXlXkX`.N       # D qXxXlXlXlXlXlXlXkX,XD   _ }.&X=Xr O j.iXxXlXlXlXlXlXlXjXA.h +   $ X   | :XxXlXlXlXlXlXlXzXsXH.- < m..X0XxXlXlXlXlXlXlXlXlXzXiXH.t     l [ U 2   o P +XbXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX`.T # +.xXlXlXlXlXlXlXlXlXkXyX| - ; ,   # D qXxXlXlXlXlXlXlXlXxXO.$ Z F..XA.2 0 ^.nXlXlXlXlXlXlXzXsX3.  5 } b $   | :XxXlXlXlXlXlXlXlXvX&Xs * <./.qXxXlXlXlXlXlXlXlXlXcX2X( O   I S.$X{.w.2 . $ V.hXzXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXi.f g n.xXlXlXlXlXlXlXlXzXfXH.w   P I   # D qXxXlXlXlXlXlXlXlXxXv.f t 7./. .1 ( %XvXlXlXlXlXlXlXzXuXq.h u.+X) =   | :XxXlXlXlXlXlXlXlXcX5Xo.< J F.eXxXlXlXlXlXlXlXlXlXvX;XC 6 5 C.hXbXnX>XA +   e.wXxXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+X[ , R XXzXlXlXlXlXlXlXlXkX,XH # - l.e.  # D qXxXlXlXlXlXlXlXlXzX.XY - ' U.k 2 d.0XxXlXlXlXlXlXlXzXpXE.C.kXtX_ =   | :XxXlXlXlXlXlXlXlXzXyXN.8 w c.rXxXlXlXlXlXlXlXlXlXxX9Xu.4.0.:XvXlXvX2XT #   q.qXxXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XP o [ 6XlXlXlXlXlXlXlXxXrXh.=   / *Xh.  # D qXxXlXlXlXlXlXlXlXlX4X] X U J.4 < H.aXzXlXlXlXlXlXlXlXkXlXzXxXrX_ =   | :XxXlXlXlXlXlXlXlXzXdX/.q * g.tXxXlXlXlXlXlXlXlXlXlXlXxXxXxXzXlXzXkX{.i o + m.fXzXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XS   o.aXlXlXlXlXlXlXlXkX|.s O 1 G.nXs.  # D qXxXlXlXlXlXlXlXlXlXpXX.  G G.* ; ^.jXzXlXlXlXlXlXlXlXlXlXlXzXrX_ =   | :XxXlXlXlXlXlXlXlXlXjX@X9 o s.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX;X=.+ X m }.bXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XC   @.xXlXlXlXlXlXlXcX<X-.@ + &.>XVXs.  # D qXxXlXlXlXlXlXlXlXlXxX@.  D F.# % }.xXlXlXlXlXlXlXlXlXlXlXlXzXrX_ =   | :XxXlXlXlXlXlXlXlXlXzX1X6   a.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzX2X7.= . > C.uXxXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XA   o.sXlXlXlXlXlXzXhXG.4 o y '.jXNXs.  # D qXxXlXlXlXlXlXlXlXlXaXo.  G F.& - /.jXzXlXlXlXlXlXlXlXlXlXlXzXrX_ =   | :XxXlXlXlXlXlXlXlXlXjX$X9 X s.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXxX1X2.1   = q.6XlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XK X { 7XlXlXlXlXlXvX XW   = u.pXBXDXh.  # F iXmXzXlXlXlXlXlXlXlX6X[ . P H.2 < K.aXzXlXlXlXlXlXlXlXlXlXlXzXrX_ =   | :XxXlXlXlXlXlXlXlXzXdX).q & f.tXxXlXlXlXlXlXlXlXlXlXlXlXlXcX:X-.4   , <.<XjXzXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+X` : W @XzXlXlXlXlXvXx.-   # U O.$.*.B   o 9 X.z.4XcXlXlXlXlXlXzXOXE * ) I.f 2 k.wXxXlXlXlXlXlXlXlXlXlXlXzXrX_ =   | :XxXlXlXlXlXlXlXlXzXuXZ.9 8 x.rXxXlXlXlXlXlXlXlXlXlXlXlXxX=X&.4   3 >.>XkXzXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXw.p z Z.xXlXlXlXlXxXq.                        A XXbXlXlXlXlXlXxXB.l w 3.~.` 1 | -XvXlXlXlXlXlXlXlXlXlXlXzXrX_ =   | :XxXlXlXlXlXlXlXlXcX7X*.1 A S.eXxXlXlXlXlXlXlXlXlXlXzXkX%X$.<   8 ,.2XbXvXvXxXzXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX~.P * &.xXlXlXlXlXzXc.e p p p p p i <     X u o.*XvXlXlXlXlXlXxX$.* B Z. Xn.2 y ).nXlXlXlXlXlXlXlXlXlXlXzXrX_ =   | :XxXlXlXlXlXlXlXlXvX*Xj = -.~.qXxXlXlXlXlXlXlXlXlXzXgX$X+.-   @ T W.>X;X;X-X7XdXzXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX8X#.  J 9XkXlXlXlXzX%XN.V.V.V.V.C.M.W     3 k.).eXxXlXlXlXlXkX8XJ   / [.&X$Xw O n.fXzXlXlXlXlXlXlXlXlXlXzXrX_ =   | :XxXlXlXlXlXlXlXzXgXR.- > c. X0XxXlXlXlXlXlXlXlXlXxX7X=.%     3 H o. . . . .x.1XxXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXaXd.6 p h.gXlXlXlXlXkXhXhXhXhXhXjXhX0.  @ A 9XlXkXlXlXlXlXlXfXf.i 9 3.@X=X0XK : Q {.cXlXlXlXlXlXlXlXlXlXzXrX) *   | :XxXlXlXlXlXlXlXcX*X} > m I.OX9XxXlXlXlXlXlXlXlXlXvX=Xk O       X o o o o X / XXvXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXuX:XX.O B 5XjXlXlXlXlXlXlXlXlXlXzXlXt.  - J wXxXlXlXlXlXlXjX4XN + X.`.oX=XsXT.p $ i.gXzXlXlXlXlXlXlXlXlXzXrX[ <   o.>XxXlXlXlXlXlXzXhXA.; 6 N.|.XX9XxXlXlXlXlXlXlXlXlXvX=Xx & @ @ @ @ @ @ @ @ + ) XXvXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXm.8 4 =.yXzXlXlXlXlXlXlXlXlXlXlX8XXX+X:XhXlXlXlXlXlXzXtX%.3 0 N.0X.X*XjXtXQ = v G.bXlXlXlXlXlXlXlXlXlXhX1X@XXX2XdXlXlXlXlXlXlXbX^.S = S 1X*X.X9XxXlXlXlXlXlXlXlXlXzXdX*XOXoXoXoXoXoXoXoXoXoX<XaXzXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXbX1X:.@ u z.uXcXlXlXlXlXlXlXlXlXlXxXbXbXcXlXlXlXlXlXcXuXk.y # >.3XeX.X*XkXkX!.c # W '.vXlXlXlXlXlXlXlXlXlXcXbXbXcXzXlXlXlXlXlXbXOX} * t K.sX=X.X9XxXlXlXlXlXlXlXlXlXlXzXvXbXbXbXbXbXbXbXbXbXbXcXzXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXlX.X~ % z v.rXbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXrXc.l % ^ XXzX0X.X*XkXlXdXl.a : ) ].cXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXbXOX+.3 0 r.uXjX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXzXfX).Z # x p.<XvXcXlXlXlXlXlXlXlXlXlXlXlXlXcXcX,Xi.z # A _.fXcX9X.X*XkXlXzXwXw.0 ; ~ U.sXcXzXlXlXlXlXlXlXlXlXlXlXlXzXcXhX/.| 3 2 -.7XlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXxXpXL.G = 8 *.).8XxXcXxXzXzXlXlXzXzXxXcXxX8X(.*.8 - H I.aXxXxX9X.X*XkXlXlXcX>X9.u % b b.#XsXvXcXzXzXlXlXlXzXzXcXvXgX*XA.S = 0 -.%XxXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXzXhX}.U 4 + h t..X,XwXaXgXlXlXgXaXwX,X.Xr.g + 4 Y  XhXzXlXxX9X.X*XkXlXlXlXxXwXx.s : % ~ H.&X5XyXdXjXzXjXdXuX7X*XR.} ; = t e.7XxXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXlXlXjX1X,.d 1 ; 3 K p.U. X:X:X XU.p.K 3 ; < s ,.1XjXlXlXlXxX9X.X*XkXlXlXlXlXlXpX/.I 0 , = a X.N./.@X1X%X_.Z.*.k - > 5 A J.yXlXlXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXrXlXkXkXkXkXkXhXuX.X;.w * : 5 q 0 7 7 0 q 5 : * w :..XuXhXkXkXkXkXlX9X.X*XjXkXkXkXkXkXjXdX6XK.G < * < 8 q 9 6 8 q 9 2 = > m V.2XsXjXkXkXkXkXjX*X.X9XlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXrXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOX%X*X*X*X*X*X*X*X-X#X).D.i.' g < @     @ < g ] p.D.).#X-X*X*X*X*X*X*X$XOX@X*X*X*X*X*X*X*X=X=XXXT.m.1.J w * X   . & 8 A ;.v.I. X*X=X*X*X*X*X*X*X@XOX$X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X%X+XOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX[.OX$X$X$X$X$X$X$X$X%X*X*XoX!.S.n.z.k.k.z.n.S.~.oX*X*X%X$X$X$X$X$X$X$XXX}.OX.X.X.X.X.X.X.X.X.XXXOXXX).L.N.c.l.j.l.x.M.H./..XOXXX.X.X.X.X.X.X.X.XOX+XoX.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.XXX+X+XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX X1.! / / / / / / / / / / ( ) ` ' ' ] ] ' ' ` ) ( / / / / / / / / / Q r.XX$X9X9X9X9X9X9X9X9X0XwXyX8X|.n.2.+.} ] } o.,.l.`.6XtXwX0X9X9X9X9X9X9X9X$XoX,X0X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X0X2XOXOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX@Xn                                                                   Q $X*XlXxXxXxXxXxXxXvXbX9XI.p.o.M 3 O       o < x { y.F.4XcXbXxXxXxXxXxXlX*X.X0XcXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXcXyXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXlXlXzXlXrX(.w.d X @ e N H L I P J V u % . e 2.E.9XlXzXlXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXlXzXjX2Xz.h & 7 f R u.).:XwXhXtX,X].h.^ j 9 $ y y.:XhXzXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXlXjX-X1.: > e <.$XdXhXjXkXkXlXkXkXjXhXfX,X0.a > = ..+XgXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXzX X] ; 3 W XXtXhXlXlXlXlXlXlXlXlXlXlXlXjXyX*X} 8 - Y ^.lXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXzX>Xo.= 0 1.:XhXzXlXlXlXlXlXlXlXlXlXlXlXlXlXzXjX4Xt.a % W $XkXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXrX-.2 w 3.2XxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX9Xp.s > ] 8XhX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXkXl.y : #.,XvXlXlXlXzXbXNXMXMXMXMXMXMXMXMXvXlXlXlXlXvX7X7.2 6 t.pX=X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXcXbXmXMXMXmXvXzXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XhX4XD + T {.nXlXlXlXlXpXR.i.s.s.s.s.s.s.a.x.{.zXlXlXlXlXnX&X} $ l #X%X.X9XxXlXlXlXlXlXlXlXlXlXlXlXcX2XW.n.h.k.Z.{.sXzXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X=XiXk.q 6 M.cXlXlXlXlXzX1XR                 ; 1.xXlXlXlXlXlXcX!.t 2 q.'.oX9XxXlXlXlXlXlXlXlXlXlXzXhXoX4.b -   . 7 T m.7XkXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X=X5Xc & @.=XcXlXlXlXlXzX#XI   O > 4 4 4 4 2 h u.xXlXlXlXlXlXcX3X4.: i G.OX0XxXlXlXlXlXlXlXlXlXlXjX>XT %   = 5 1 +   : g.qXxXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / %X#X}.7 $ H.xXlXlXlXlXlXzX'.D   8 @.a.s.s.s.a.c.}.zXlXlXlXlXlXlXzX{.< = f.{.0XxXlXlXlXlXlXlXlXlXxXqXr.;   , ) j.6.c O X r ~.vXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / &X].y.2 c [.bXlXlXlXlXlXzXT.M   c `.uXpXpXpXiXaXfXlXlXlXlXlXlXlXcX:XS ; | T.wXxXlXlXlXlXlXlXlXlXcX:XS #   2.>XsXiX(.i o   h.iXzXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / *XR.L 2 >.1XcXlXlXlXlXlXzXA.k   V <XxXcXcXcXxXzXlXlXlXlXlXlXlXlXxXqXw.4 z B.eXxXlXlXlXlXlXlXlXlXcX,XT c M ^.xXzXvX1XE #   8.8XxXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / =XJ.t 1 m.tXxXlXlXlXlXlXxXl.p   B ^.2.~ ! =.R.yXxXlXlXlXlXlXlXlXzXpXL.0 2 k.rXxXlXlXlXlXlXlXlXlXzXaX.X[.|.tXxXlXbX,XV +   a.yXxXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / =XF.> > Y.fXzXlXlXlXlXlXxXt.0   5 G :     ; n d.9XzXlXlXlXlXlXlXzXgX{.0 # d.tXxXlXlXlXlXlXlXlXlXlXzXbXbXbXzXlXcXpXA.2 X 2 L.zXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / -XS.$ * '.lXlXlXlXlXlXlXxX8.3   X e H L y O   p v.lXlXlXlXlXlXlXlXkX-X7   a.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXfXE.D . X X.:XvXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / -XS.# & [.xXlXlXlXlXlXlXzXH.| S R d..XOXh.l o   K 7XkXlXlXlXlXlXlXlX,X6   a.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXxXdX~.E   o n [.hXzXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / -XD.- : E.gXzXlXlXlXlXlXlXxXxXrX7XzXzXzXcX0.7   h Y.jXlXlXlXlXlXzXhX.X0 + d.tXxXlXlXlXlXlXlXlXlXlXlXlXlXzXdX~.U   O g I.pXzXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / =XH.9 1 C.uXzXlXlXlXlXlXlXfXaXaXfXlXlXlXzXU.n   y v.hXlXlXlXlXlXzXaXR.q > h.tXxXlXlXlXlXlXlXlXlXlXlXlXlXfXW.D   X g G.pXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / =XU.B 2 w.6XcXlXlXlXlXlXgX/.B.D.|.lXlXlXzXP.b   p V.hXlXlXlXlXlXxXrXh.6 a n.rXxXlXlXlXlXlXlXlXlXlXlXlXfXU.M X   z J.pXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / &X_.1.1 G XXbXlXlXlXlXlXlX .5 7 [ rXzXzXzX3.3   x [.jXlXlXlXlXlXcX<XR > ^ P.wXxXlXlXlXlXlXlXlXlXlXzXdXG.c +   n H.aXxXzXzXzXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / %XOXQ.4 > R.bXlXlXlXlXlXzX5.1   3 ..F.W.9.s . + _ uXlXlXlXlXlXlXcX+X8 * e.`.qXxXlXlXlXlXlXlXlXlXzXyXA.x O   , ~ b.F.S.S.S.[.eXzXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*X1Xs @ 7.6XcXlXlXlXlXzX#X_ +   * z N 6     A E.cXlXlXlXlXlXxXwXh.- 8 Z.oX0XxXlXlXlXlXlXlXlXlXcX<XT o     = u c l l l k ,.&XcXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X=XyX:.4 h L.vXlXlXlXlXlXzX/...d *     + r ~ K.fXlXlXlXlXlXlXvX[.m <  .^.OX9XxXlXlXlXlXlXlXlXlXvX&Xu                     U |.vXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XgX%Xb X O.<XcXlXlXlXlXlXvX3Xm.$.~ Q ..f.=XzXzXlXlXlXlXlXcX7X6.+ i _.@XXX9XxXlXlXlXlXlXlXlXlXcX4X$.Y P P P P P P P P P t.:XcXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXhX,.7 8 q.iXzXlXlXlXlXlXzXzXxXxXcXxXxXzXlXlXlXlXlXlXxXsXx.r 2 o.rX=X.X9XxXlXlXlXlXlXlXlXlXlXlXxXcXcXcXcXcXcXcXcXcXcXxXzXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXkX3XQ % z c.aXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXF.V & Z =XgX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXkX}.U @ l l.aXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXZ.B # M ^.gXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXgXI.S # s -.6XlXzXlXlXlXlXlXlXlXlXlXlXlXlXlXrX8.l % x V.sXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXxXuX!.^ + 6 P x.8XnXvXxXzXzXlXzXzXxXvXbXtXC.Q q + J L.rXzXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXlXcXfX}.#.9 . f ` q.K.*X0XfXvXgXwX-XT.t.| x X 2 [ ~.sXcXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX@Xm                                                                   ! $X*XlXzXzXzXzXcXzX2Xd.( 9   * m  .1.q.i.w.3.o.Z >   3 R e.*XlXcXzXzXzXlX*X.X0XcXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXcXyXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX.Xo.m B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B n 1.OX%XrXtXtXtXtXtXtXuXuX}.=.F h 7 = +       O * 5 f S o.(.rXiXtXtXtXtXtXrX%XXX2XyXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXyX6XoXOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX]..X@X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X@X X{.+XoXoXoXoXoXoXoXoXoXoX+X].N.&.H z s u a l D O.v.`.OXoXoXXXoXoXoXoXoXoX+X+XOXXXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXXoX+XXXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXOX+XOXoXoXoXoXoXoXoXoXoXoXoXoXXX X|.}.}.}.}.}.|. X.XoXoXoXoXoXoXoXoXoXoXoXOX+XOXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXOXXX'.XXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXOXOXOXOXOXOXOXOXOXXX X|.}.}.}.|. XoXOXOXOXOXOXOXOXOXoXOX.X{.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.{..XOXoXOXOXOXOXOXOXOXOXOXXX X|.}.}.}.|. XoXOXOXOXOXOXOXOXOXOXoXoXoXoXoX",
"oXoXoXoX+X.X}.|.}.}.}.|.}.].`..X-X2X4X5X4X2X=X X`.].}.|.}.}.|.}.XX}.*X7X4X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X4X7X*X}.XX}.|.}.}.}.|.}.].`..X-X2X4X5X4X1X=X X`.[.}.|.}.}.|.}..X+XoXoXoXoX",
"oXoXoXoX.X<XwX9X0X0X0X8X5XpXkX$Xd.@.[ ` { $.j.*XlXiX5X8X0X0X9XwX,X%X0.I / ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ / I 0.%X,XwX9X0X0X0X8X5XaXkX@Xa.@.[ ` { $.l.-XlXuX5X8X0X0X9XwX<XXXOXoXoXoX",
"oXoXoXOX}.wXMXcXvXvXxXMXDXR.` N =           : V [ /.GXmXxXvXcXMX8X2XK                                                     K 2X8XMXcXvXvXxXNXSXP._ M *           > Z { `.GXmXxXvXcXMXwX}.OXoXoXoX",
"oXoXoXOX|.9XcXjXkXkXmX%XY 4   +  .m.R.[.Y.b.] .   5 E ,XnXkXjXcX6X<X~   $ O O O O O O O O O O O O O O O O O O O O O O $   ~ <X6XcXjXkXkXmXOXP 2   $ o.M.R.[.U.v.)     7 ~ 3XnXkXjXcX9X|.OXoXoXoX",
"oXoXoXOX}.0XvXkXzXnXY.2   t U.qXsXvXMXCXMXcXaX0XF.7   7 /.mXkXvX6X<XW   O                                             O   W <X6XvXkXzXnXJ.,   a E.qXdXvXNXCXMXcXpX0XZ.3   0 '.mXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XvXkXnXl.+ + 5.hXxXmXcXlXkXjXkXlXcXmXxXdX-.O & N.mXxX7X<XW   O                                             O   W <X6XvXkXbXf.o $ q.jXxXmXcXlXkXjXkXlXcXmXxXsX#.X - S.mXxX0X}.OXoXoXoX",
"oXoXoXOX}.0XxXmXY.+ > S.VXzXlXkXkXjXhXhXhXjXkXkXlXxXBXn.& = ^.VX4X<XW   O                                             O   W <X7XxXmXJ.X 2 K.VXlXlXkXlXlXjXhXhXhXkXkXlXxXNXl.@ > `.VX7X|.OXoXoXoX",
"oXoXoXOX|.8XMX$X1 # S.VXjXlXlXjXlXNXSXFXSXmXkXkXlXlXkXBXn.  q 4X0X>XQ   O                                             O   W <X5XMXOX; * K.VXjXlXlXlXlXhXmXFXGXAXxXlXlXlXlXBXl.  u 8XeX{.OXoXoXoX",
"oXoXoXOX}.5XFXU   5.VXjXlXlXhXnXcX*X^.E./.<XnXxXkXlXlXkXMX-.  { aX-XW   O                                             O   W <X2XSXD   q.CXhXlXlXlXlXjXZX1XI.J./.sXzXkXlXlXlXnX#.  @.hX`.OXoXoXoX",
"oXoXoXOX].pXE.4 t gXzXlXlXjXbXwX8.a       k x.gXlXkXlXkXcXiX6 r V.0XT   O                                             O   W :XyXP.< a zXkXlXlXlXlXlXMX~.m     3 2XcXjXlXlXkXbXwX1 p J.$X.XoXoXoX",
"oXoXoXOX`.lX`   U.xXlXlXkXjXxX=.    u G 5     z.CXgXlXlXlXxXC.  E pXU   O                                             O   W -XfXE   Q.xXlXlXlXlXjXvXf.*   &   k 5XxXjXlXlXlXlXxXb.  [ ,X|.oXoXoX",
"oXoXoXXX.X#XM + qXmXkXlXgXVXQ.+   R XX9XY.p   S uXxXkXlXjXBX1X. l &XQ   O                                             O   E 3X Xz & uXbXkXlXlXkXhXcXr   %.b   f 4XxXjXlXlXlXjXVX=X  V `.+XXXoXoX",
"oXoXoX X-Xd.=  .sXcXlXlXjXnX;XM.h.3XMXNXnX]   B 1XbXjXlXkXvXuX) o A.'   O                                             O   Y tXq.& @.fXxXlXlXlXkXkXgXP j.lXU   f 4XxXjXlXlXlXkXvXrXQ & l.;X XoXoX",
"oXoXoX|.2X#.  m.vXlXlXlXlXkXcXMXNXvXNXlXZ.<   +.NXhXkXlXlXlXcXf.  u. .  O                                             O   U dX'   A.vXlXlXlXlXlXlXhX5XnXzXH   f 4XxXjXlXlXlXlXlXxXy.  5.1X|.oXoX",
"oXoXoX}.4X[   E.NXkXlXlXlXlXlXjXlX6Xt = + # ,.uXcXkXlXlXlXkXNXD.  9.X.  O                                             O   I gXR   (.MXkXlXlXlXlXlXlXnXxXhXJ   f 4XxXjXlXlXlXlXjXBXM.  >.3X|.oXoX",
"oXoXoX}.5X`   [.CXjXlXlXlXlXkXjXlX5X1     # | <XvXjXlXlXlXjXSXE.  8.X.  O                                             O   I gXU   OXVXkXlXlXlXlXlXlXkXzXjXJ   f 4XxXjXlXlXlXlXhXDXJ.  :.3X|.oXoX",
"oXoXoX}.4X[   Y.MXkXlXlXlXlXxXbXbXhX:X#Xt.:   v 3XbXjXlXlXkXNXA.  0.X.  O                                             O   I gXE   ^.mXkXlXlXlXlXlXlXlXxXjXJ   f 4XxXjXlXlXlXlXkXNXm.  >.3X|.oXoX",
"oXoXoX|.2X$.  b.cXlXlXlXlXzXsXrXrXlXlXzXnXi.    b.HXgXlXlXzXxXs.  i. .  O                                             O   U sX]   C.vXlXlXlXlXlXlXlXlXxXjXJ   f 4XxXjXlXlXlXlXzXzXr.  5.1X|.oXoX",
"oXoXoX X=Xj.: ] aXcXlXlXgXSXA.J P *XDXmXAXk.    g.KXfXlXkXvXtXQ @ F.'   O                                             O   Y rXt.- ..dXxXlXlXlXlXlXlXlXxXjXJ   f 4XxXjXlXlXlXkXbXwXU - x.-X XoXoX",
"oXoXoXoX X*XC . 0XmXkXlXfXGXc.    K !.-XG.d   - E.ZXgXlXjXBX,X  c -XW   O                                             O   E 2X+Xv @ yXnXkXlXlXlXlXlXlXxXjXJ   f 4XxXjXlXlXlXjXCX&X  A ].OXXXoXoX",
"oXoXoXOX`.lX[   F.xXlXlXkXlXdX'     4 z :     -.kXkXkXlXlXzXb.  ! pXU   O                                             O   W -XgX!   P.xXlXlXlXlXlXlXlXxXjXI   l 5XxXjXlXlXlXlXzXk.  } <X|.oXoXoX",
"oXoXoXOX[.iX(.6 7 dXxXlXlXjXmX9X5.p       z s.yXbXjXlXkXvXeX: u G.8XT   O                                             O   W :XrXQ.2 e jXlXlXlXlXlXlXlXxXjXb   5 2XcXjXlXlXkXbX8X* f Y.#X.XoXoXoX",
"oXoXoXOX}.5XGXW   =.BXkXlXzXhXmXzX:X|.]..X2XbXbXhXzXlXlXnX .  o.sX-XW   O                                             O   W <X2XDXL   1.VXjXlXlXlXlXlXlXlX#X^..XdXzXlXlXlXzXcX'   =.jX`.OXoXoXoX",
"oXoXoXOX|.8XmX,X7 o n.BXkXkXlXjXzXNXZXAXCXmXlXjXlXkXlXNXf.  u qX9X,XQ   O                                             O   W <X5XmX=X1 # C.VXkXkXlXlXlXlXlXBXSXCXzXlXlXkXzXMXu.  f rXwX{.OXoXoXoX",
"oXoXoXOX}.0XxXnX/.& & b.MXcXlXkXkXjXjXjXjXjXkXjXlXvXnXf.O , }.BX4X<XW   O                                             O   W <X7XxXnXE.+ - B.NXcXlXjXkXlXlXjXhXjXkXjXzXvXbXu.. 4 oXBX7X|.OXoXoXoX",
"oXoXoXOX}.0XvXkXmXN.=   *.yXxXBXvXlXkXjXkXzXvXBXzXeX..  , H.mXcX7X<XW   O                                             O   W <X6XvXkXnXc.% X ,.iXcXBXcXlXkXjXkXzXvXBXzXqX]   3 I.mXxX0X}.OXoXoXoX",
"oXoXoXOX|.9XcXjXkXmX^.q   4 C.<XyXcXNXSXNXxXtX,Xn.:   y }.mXjXcX6X<X!   # o o o o o o o o o o o o o o o o o o o o o o #   ! <X6XcXjXlXmXE.8   9 D.1XuXcXBXSXNXxXrX,Xx.*   a oXnXjXcX9X|.OXoXoXoX",
"oXoXoXOX}.wXMXcXvXxXVX4X} t     ) f.D.E.S.s.!     u o.0XBXcXcXMX8X2XK                                                     K 2X8XMXcXvXxXCX<X] w   X ` g.F.E.A.a.E     p @.rXBXcXcXMXwX}.OXoXoXoX",
"oXoXoXOX X1XtXwXeXeX0XyXkXG.( b @           $ M _ U.lXtX0XeXwXtX<X%X6.F E Y Y Y Y Y Y Y U L K J J J K L U Y Y Y Y Y Y E F 6.%X<XtXwXeXeX0XuXjXA.^ b %           ; V ' E.zXtXqXeXwXtX1X.XOXoXoXoX",
"oXoXoXXX+X|.`.'.'.'.'._./. X$X/.v.r.9.7.9.t.n.).$X|./._.'.'.'.`. X X$X2X<X<X<X<X<X<X:X-X3XtXdXgXgXgXsXrX2X-X:X<X<X<X<X<X2X$X X X`.'.'.'.'._./.OX-XQ.y.&.o...O.=.d.).;X.X/.`.'.'.'.`.|.#XOXoXoXoX",
"oXoXoXOX.X1XrXqXwXwXwX0X7XiXfX%Xc.1.*.#.*.3.n.*XgXuX7XqXwXwXqXrX2X X,X7X5X5X5X6X4X1XtXdX.Xe.{ ~ E ~ | p.@XfXrX1X4X6X5X5X7X,X X2XrXqXwXwXwXwXwX9X7XeXdXlXzXxXzXkXsXqX6X9XwXwXwXwXqXrX1X.XOXoXoXoX",
"oXoXoXOX}.wXMXcXvXvXxXMXSXU.^ v $           * m ) !.FXmXxXvXcXMXtX`.rXMXcXvXvXxXNXSXP.^ b *           ; M _ ^.FXmXxXvXcXMXrX`.tXMXcXvXvXvXvXvXvXvXcXzXlXkXkXkXlXzXcXvXvXvXvXvXvXcXMXwX}.OXoXoXoX",
"oXoXoXOX|.9XcXjXkXkXnX@XL 2   $ o.B.Q. XW.M.} o   3 U ;XnXkXjXcXwX'.qXcXjXkXkXmXOXK 1   % +.V.!. XE.M.[ X   4 T ,XnXkXjXcXqX'.wXcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX9X|.OXoXoXoX",
"oXoXoXOX}.0XvXkXzXnXP.,   i R.rXdXvXMXVXMXcXsXeXJ.0   4 !.nXkXvXeX'.wXvXkXzXnXJ.>   a W.rXdXvXMXVXMXcXsXeXG.8   5 /.nXkXvXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XvXkXnXh.o # 8.kXxXnXxXlXkXjXkXlXcXnXxXhX>.@ # n.mXxXeX'.wXvXkXnXf.X % q.lXxXnXxXlXkXjXkXlXcXnXxXgX-.+ % N.mXxXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XxXmXP.O < G.VXlXlXkXlXlXkXhXgXgXjXlXlXzXVXN.= & Q.CX0X'.wXxXmXJ.X 2 K.VXlXlXkXlXlXjXhXgXhXkXkXlXzXBXn.& - ^.CX9X'.eXvXkXlXlXlXlXlXlXlXlXkXjXhXhXhXkXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX|.8XNX@X< $ G.VXjXlXlXlXlXlXzXFXGXGXNXkXlXlXkXVXM.. 9 2XuX_.0XNXOX: & K.VXhXlXlXlXlXgXmXGXHXSXxXlXlXlXkXBXn.  w 4XyX_.eXvXkXlXlXlXlXlXlXlXhXzXCXFXFXAXvXhXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.5XDXP   8.VXjXlXlXlXlXlXkXfXK.G.G.%XnXjXlXlXkXMX>.  [ jX/.7XSXH   q.VXhXlXlXlXlXhXAX<XH.S.Q.aXzXkXlXlXkXmX-.   .jX/.eXvXkXlXlXlXlXlXzXhXNXgX XR.U.(.wXBXjXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX].pXT.3 u hXzXlXlXlXlXlXjXVXa.      %.JXdXlXlXkXcXpX8 e D..XiXI.1 a kXlXlXlXlXlXkXMXQ.m     , <XcXjXlXlXkXvXyX5 t G.OX0XvXkXlXlXlXlXlXjXMX1Xo.3     + G ^.nXhXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX`.lX_   T.xXlXlXlXlXlXkXzX1X3   # o 6.FXfXlXlXlXlXxXA.  / #XgX~   W.xXlXlXlXlXjXvXd.&   &   g 3XxXjXlXlXlXlXxXV.  ` -X8XvXkXlXlXlXlXkXkXfX!     m F +   5  XBXhXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXXX.X@XM # qXmXkXlXlXlXlXgXVX/   5     3.GXfXlXlXlXjXBX1XX c ^.#Xc % rXnXkXlXlXkXhXvXi   =.M   p 2XxXjXlXlXlXjXBX>X  M !.rXxXkXlXlXlXlXgXAXS.%   @.,X0Xj.%   $.CXhXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX X-Xs.* X.sXcXlXlXlXlXgXVXK.%   m.    3.GXfXlXlXlXkXvXuX_ + v.z.# +.dXxXlXlXlXkXkXhXT j.xXR   a 2XxXjXlXlXlXkXvXyX/ & a.fXzXkXlXlXlXlXfXGXh.8 q 1XZXCXtXc   ~ sXzXkXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX|.2X@.  M.vXlXlXlXlXkXlXpXm   Q eX    3.GXfXlXlXlXlXlXcXf.  r.1.  V.vXlXlXlXlXlXlXhX8XbXcXL   a 2XxXjXlXlXlXlXlXxXa.  ;.lXlXkXlXlXlXlXkXxXyX3X5XjXjXmX2Xq   } bXkXkXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.4X[   E.NXkXlXlXlXfXDX9.  . -XpX    3.GXfXlXlXlXlXkXBXF.  9.&.  ~.MXkXlXlXlXlXlXlXnXzXkXP   a 2XxXjXlXlXlXlXkXBXZ.  #.xXkXkXlXlXlXlXlXkXvXMXmXlXxXxX6.  o m.DXgXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X`   [.CXjXlXlXhXBXXXy   ,.cXeX    1.SXdXlXlXlXlXjXSXE.  8.$.   XVXjXlXlXlXlXlXlXkXzXlXP   a 2XxXjXlXlXlXlXhXSXU.  @.xXkXkXlXlXlXlXlXlXkXkXjXxXvXk.    ` zXkXkXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.4X[   Y.MXkXlXkXlXxX}   j pXUXkX    0.UXjXkXlXlXlXkXMXA.  9.&.  E.MXkXlXlXlXlXlXlXlXzXlXP   a 2XxXjXlXlXlXlXkXNXB.  #.xXkXkXlXlXlXlXlXlXlXjXxXcXg.    D qXcXjXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX|.1X$.  v.cXlXlXhXSXK.&   #._.'.I.    _ %XqXcXkXlXlXzXxXa.  t.3.  M.cXlXlXlXlXlXlXlXlXzXlXP   a 2XxXjXlXlXlXlXzXzXu.  :.lXlXkXlXlXlXlXlXlXjXxXzXt.    C 3XxXgXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX X=Xk.: ' aXcXkXgXGXe.            . O     W.ZXgXlXkXvXrXE % m.m.* { sXcXlXlXlXlXlXlXlXzXlXP   a 2XxXjXlXlXlXkXvXeXT ; g.dXzXkXlXlXlXlXlXjXvXkX7.    U yXZXnXmXzXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXoX X=XZ   0XmXkXhXZXA.t M m B V l     - ^ oXNXjXlXjXBX,X  M ).-XM X eXnXkXlXlXlXlXlXlXzXlXP   a 2XxXjXlXlXlXjXVX-X  Z (.eXcXkXlXlXlXlXkXlXiX>.    r R.%XXXoX-XdXzXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX`.lX{   S.xXlXkXxXtX;X,X>X>X2X(..   } pXyXzXlXlXlXzXc.  ` $XhX_   G.xXlXlXlXlXlXlXlXzXlXT   g 3XxXjXlXlXlXzXzXl.  [ -X8XvXkXlXlXlXlXgXAXZ.+ O $ w l f k u ^ 1XnXjXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX[.uX`.7 5 sXxXlXlXcXmXnXnXnXVX4X    >.UXgXlXlXkXvXwX- p Y.|.uX(.4 8 fXzXlXlXlXlXlXlXzXlXN   2 <XcXjXlXlXkXbX0X* s R.XX0XvXkXlXlXlXlXdXKX7.                5 %XMXjXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.5XHX!   %.NXkXlXkXjXjXjXjXkXaX'.].1XxXjXlXlXzXbX{   +.lX/.7XGXR   =.BXkXlXlXlXlXlXlXlX*X`.OXdXzXlXlXlXzXvX'   %.lX/.eXvXkXlXlXlXlXkXvX7X[.[.[.{.}.}.|.[.$XsXzXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX|.8XmX1X9 X c.BXlXkXlXlXlXlXlXxXAXAXmXkXlXkXzXNXa.  p wXtX_.qXmX,X5 O n.BXkXkXlXlXlXlXlXNXAXVXzXlXlXkXzXMXu.  d rXrX_.eXvXkXlXlXlXlXlXkXnXAXZXZXAXAXAXZXAXVXxXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XxXnX_.* $ x.mXvXlXjXkXlXlXlXjXhXjXjXlXbXbXa.X 1  XBXqX'.wXxXnX/.% & b.mXvXlXjXkXlXlXjXjXjXkXjXlXbXvXu.. 3 oXBX0X'.eXvXkXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXjXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XvXkXmXC.;   $.rXxXVXvXlXkXhXkXzXvXVXzXqX}   2 L.mXcXeX'.wXvXkXnXN.-   *.tXcXBXvXlXkXhXkXzXvXVXzX0X]   3 I.mXxXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX|.9XcXjXkXmX).r   2 N.:XtXxXBXSXNXxXeX;Xx.-   a  XmXjXcXwX'.qXcXjXkXmX^.w   4 V.:XyXxXBXSXNXzXeX-Xl.*   d oXmXjXcXqX'.wXcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX9X|.OXoXoXoX",
"oXoXoXOX}.wXMXcXvXxXVX6Xo.u     ^ a.C.U.V.i.E     a #.wXBXxXcXMXtX`.rXMXcXvXxXCX4X..y     / a.Z.U.V.u.T     s %.rXBXxXcXMXrX`.tXMXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXMXwX}.OXoXoXoX",
"oXoXoXoXXX>X7X5X5X6X3X9XaXA.~ c O           # n ( J.dX8X3X6X5X7X<X X2XrXqXwXwX9XyXjXG.` m @           & C { E.lXrX0XwXqXrX2X}.3XrXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXrX1X.XOXoXoXoX",
"oXoXoXOX}.$X2X<X<X<X<X>X-X9XpX=XF.s.e.q.r.s.H.:XaX8X-X,X<X<X<X2X%X X X`.'.'.'.'._./. X$X/.m.i.e.q.e.p.N.`.%X}./._.'.'.'.`.}.$X}.`.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.`.|.#XOXoXoXoX",
"oXoXoX.X=X8.D E Y Y Y T Y P K T ( [ { } { [ ( Y K I Y T Y Y R F 4.%X<XtXwXeXeXeXqX9XpXgX#Xk.:.@.o.#.,.v.*XhXiX9XwXeXeXwXtX3X}.3XtXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXtX1X.XOXoXoXoX",
"oXoXoX{.7XU                                                     F 2X7XMXcXvXvXxXNXAXH.E l #           * v ~ Q.DXmXxXvXcXMXrX`.tXMXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXMXwX}.OXoXoXoX",
"oXoXoX}.4X/   # o o o o o o o o o o o o o o o o o o o o o o #   R <X5XcXjXkXkXmXXXF ,   = $.A./.OX~.V.| +   2 P ;XnXkXjXcXqX'.wXcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX9X|.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X5XvXkXzXbXF.-   f ~.uXgXvXMXVXmXcXdXyXK.q   3 !.nXkXvXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X5XvXkXnXa.  * r.xXxXbXxXlXkXkXkXlXxXnXxXjX,.# # n.mXxXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X6XxXmXF.. 4 P.CXkXlXhXgXgXgXgXgXgXgXjXlXlXVXN.= * Q.CX9X'.eXvXkXlXlXlXlXlXlXlXlXkXhXhXgXhXjXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X4XNX.X; = P.CXhXlXlXZXJXGXHXHXHXHXGXmXkXlXjXVXM.  q 2XyX_.eXvXkXlXlXlXlXlXlXzXhXzXCXFXGXSXbXhXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X1XSXG   r.VXhXlXkXlX).N.F.F.F.G.F.J.2XbXkXlXkXMX>.  | hX/.eXvXkXlXlXlXlXlXzXgXNXfX[.P.K.!.0XBXjXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y :XyXK.< d lXlXlXkXlXdXj               j.GXfXlXkXvXuX7 r D.OX9XvXkXlXlXlXlXlXhXMX,X .1     O S Q.nXhXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y -XfX~   !.xXlXlXjXcX7XN   d H H J G I ^.VXhXlXlXlXcXZ.  _ -X8XvXkXlXlXlXlXkXlXdXW     B J @   3 }.VXhXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   U 3X|.c & rXnXkXlXjXnX*Xh   r.4X1X<X2X5XaXxXlXlXlXjXBX>X. m Q.rXxXkXlXlXlXlXgXAXA.$   %.1XwXz.&   #.CXhXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   L tXw.& @.fXxXlXlXhXNX[.y   Y.LXLXKXSXnXxXlXlXlXlXkXvXyX) % p.fXzXkXlXlXlXlXfXGXj.0 r 2XZXCXyXc   ~ sXzXkXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   K dX{   C.vXlXlXlXgXCXT.5   D.#.y k 7.rXcXkXlXlXlXlXlXcXs.  ;.lXlXkXlXlXlXlXkXxXiX6X8XjXjXmX1X0   } bXjXkXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   J gX!   ~.MXkXlXlXgXSXC.o   = .       G 0XcXjXlXlXlXkXBXZ.  #.xXkXkXlXlXlXlXlXkXcXmXnXlXxXzX3.  O N.DXgXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   J gXW    XVXjXlXlXgXZXI.i * K T.^.I     1.AXgXlXlXlXhXSXU.  @.xXkXkXlXlXlXlXlXlXlXkXjXxXcXg.    ] xXkXkXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   J gX~   E.MXkXlXlXlXkXbXSXwXlXbXVXeXg   A 7XvXjXlXlXkXMXB.  $.xXkXkXlXlXlXlXlXlXlXjXxXxXa.    H wXxXjXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   K sX .  m.cXlXlXlXlXlXdXtXsXhXgXkXiX&.  z &XMXjXlXlXzXzXy.  >.lXlXkXlXlXlXlXlXlXhXxXzXw.    S 5XzXgXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   L rXa.: ] sXcXlXlXhXZXB.U ' eXZXVXhXH   A 6XvXjXlXkXbXwXU : g.dXzXkXlXlXlXlXlXjXvXjX4.    R iXZXnXmXzXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   U 1X#XN . eXmXkXlXfXJXy.    X.+X1Xt.$   #.BXhXlXlXjXVX-X  A ).wXcXkXlXlXlXlXkXzXuX-.    t T.#X X.X*XdXzXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y -XgX_   D.xXlXlXkXzXiXT     a c .   d :XMXhXlXlXzXzXj.  { -X8XvXkXlXlXlXlXgXAXC.O O # 0 j a h t ! 1XnXjXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y :XeX_.5 6 dXzXlXlXjXnX4X;.0     >  .*XnXhXlXlXkXbX9X% d E..X0XvXkXlXlXlXlXdXKX8.                6 %XMXjXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X1XGXW   &.BXkXlXzXhXMXjX>X@X+X-XdXNXjXlXlXlXxXcX)   *.lX/.eXvXkXlXlXlXlXkXcX9X X X X.XXXXXoX.X*XdXzXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X4XmX1X7 o c.BXlXkXlXjXxXNXCXCXBXcXjXlXlXkXxXmXr.  g yXeX_.eXvXkXlXlXlXlXlXkXbXZXZXZXZXZXZXCXZXBXxXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X6XxXnX_.& $ x.nXvXlXjXkXjXjXjXjXkXkXjXzXnXcXr.  5 +XBX0X'.eXvXkXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXkXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X5XvXkXnXC.:   $.wXxXVXvXlXjXhXkXzXbXCXzX7X_   6 T.mXxXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.4X/   $ O O O O O O O O O O O O O O O O O O O O O O #   E <X5XcXjXkXmX).y   2 m.=XrXxXBXDXNXzXqX&Xh.$   h +XmXjXcXqX'.wXcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX9X|.OXoXoXoX",
"oXoXoX{.7XI                                                     D 2X7XMXcXvXxXCX6X@.i     ! u.N.K.m.r.U     f -.tXBXxXcXMXrX`.tXMXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXMXwX}.OXoXoXoX",
"oXoXoX.X*Xq.I / ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ / U 8.$X>XwX9X0X0X7XeXgXH.[ V &           ; S  .E.jXqX7X0X9XwX1X|.1XwX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XwX,XoX+XoXoXoX",
"oXoXoXOX}.*X7X4X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X4X7X=X|.oX}.|.}.}.|.{.'.$X<X_.k.4.>.;.>.6.c.{.<X@X`.{.|.}.|.}..X#X.X}.|.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.|.}.oX.X XOXoXoX",
"oXoXoXoX+X.X{.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.{..X+XOXOXOXOXOXOXOXOX.X|.+X;X1X3X3X3X1X-XOX|..XOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOX+X X XOXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXX X|.|.|.|.|. XXXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXOXOXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXOXoXXXXXXXXXXXXXXX X XoX@X#X#X#X@XOX.X X.XXXXXXXXXXXXXoX@X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#XoXoXXXXXXXXXXXXX.X X.XOX@X#X#X#X@XoX X XXXXXXXXXXXXXoXoXoXoXoXoX",
"oXoXoXoX+X@X@X@X@X@XOXoX-X>X@X{.'.'.'.[.XX-X>X@XoX@X@X@X@X#X}.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(./.[.@X@X@X@X@X@XoX@X>X-XXX[.'.'.'.{.@X>X-XoXOX@X@X@X@X+XOXoXoXoXoX",
"oXoXoXXX@XzXzXzXzXjXvXZX4XW.X.2       $ D N.#XcXVXhXzXlXvX8X:Xh                                               - oX3XbXkXzXzXhXVXcX#XN.D #       3 X.W.4XZXvXjXzXlXvX-X.XoXoXoXoX",
"oXoXoXXX@XzXlXlXjXmXtXk.r   * K ` ..{ Q y     *.@XVXjXkXvX8X;Xk   X                                           : oX3XvXkXkXjXVX@X=.    u Q { ..` K *   t j.yXmXjXkXvX-X.XoXoXoXoX",
"oXoXoXXX@XzXlXjXNX=XV   p l.{.iXnXHXVXhX=XG.^   , B.MXkXcX8X;Xk   X                                           : oX3XvXjXlXMXB.,   ( G.=XhXVXHXnXiX{.l.u   V -XNXjXvX-X.XoXoXoXoX",
"oXoXoXXX@XzXjXNX`.w   7.wXCXVXzXjXfXhXlXmXFXgXT.9   w.xXvX7X;Xk   X                                           : oX3XvXkXcXw.  9 R.hXFXmXlXhXfXjXxXCXCXqX7.  w `.MXzX-X.XoXoXoXoX",
"oXoXoXXX@XjXmX=Xw $ H.VXbXgXhXgXfXfXfXgXhXgXzXCX1XN   c.CX6X:Xk   X                                           : oX3XcXmXc.  N 1XCXzXgXjXkXhXdXdXgXhXgXbXVXG.$ w =XBX&X.XoXoXoXoX",
"oXoXoXXXOXvXtXB   H.ZXkXkXlXhXnXGXKXHXBXjXkXkXgXNX5Xh . ].yX-Xk   X                                           : oX1XCX^.X j 5XNXgXkXlXlXgXBXLXPXCXlXlXjXkXZXG.  V aX>X|.oXoXoXoX",
"oXoXoXXXoXZXk.  7.VXkXlXlXlXBX*Xx.r.d.'.bXcXkXlXgXCX{.O B wX-Xk   X                                           : XX1XBXb O {.CXgXlXlXlXkXSX].8.1.W.zXlXlXlXkXVX7.  x.7X}.oXoXoXoX",
"oXoXoX X-X4Xt i qXbXjXlXlXnXf.9       = *.aXxXkXzXgXAXO.$ e.qXf   X                                           : |.iXN.o +.AXgXzXlXlXlXxXd.:     [ xXlXkXlXjXbXqXy p ^.$XXXoXoXoX",
"oXoXoX X>XW.  l.CXgXlXkXnXU.    m r.E     k.BXjXlXlXxX7X  A 0Xf   X                                           : |.tX(   9XxXlXlXlXhXVX3.  O 5   =.zXlXlXlXlXhXCXj.  k.*XXXoXoXoX",
"oXoXoXoX@X .* {.CXhXlXjXMX6.1 ! qXcXhX~   / dXxXkXlXxXkXV 6 `.c   X                                           - %X^.a B lXxXlXlXkXhXBXT 7 ).B   *.zXlXkXlXlXhXCX[.= W oXOXoXoXoX",
"oXoXoX@X{.2 K iXzXkXlXlXlXfXsXhXGXPXqXA   &.vXkXlXlXlXvXh.  b.V   X                                           * 1Xa.  k.vXlXlXlXlXlXxXG.5XxXn   *.zXlXkXlXlXkXxXuXJ > [.@XoXoXoX",
"oXoXoX#X'.  ' mXjXkXlXlXlXlXkXxXN.| Z X U :XnXjXlXlXkXMXT.  s.A   X                                           * 4X6.  E.MXkXlXlXlXlXkXBXmXyXm   *.zXlXkXlXlXkXjXnX`   '.#XoXoXoX",
"oXoXoX#X'.  ..HXfXlXlXlXlXjXgXvXD     & t.zXzXkXlXlXjXVX X  p.A   X                                           * 5X2.   XVXjXlXlXlXlXlXhXxXiXm   *.zXlXkXlXlXlXfXHX..  '.#XoXoXoX",
"oXoXoX#X'.  { VXhXlXlXlXlXcXcXcX&X~.9.-   +.jXzXkXlXkXNX/.  a.A   X                                           * 5X4.  /.NXkXlXlXlXlXlXkXcXiXm   *.zXlXkXlXlXlXhXVX{   '.#XoXoXoX",
"oXoXoX@X[.$ Q hXlXkXlXlXlXiXeXsXvXxXmXy.  # *XNXjXlXkXnXV.  k.C   X                                           * 2Xe.  Z.nXkXlXlXlXlXlXkXcXiXm   *.zXlXkXlXlXkXlXgXE + ].#XoXoXoX",
"oXoXoXOXXXD u =XmXjXlXjXNXX.x 9.FXMXGXh.    @XBXjXlXzXlX[ & U.n   X                                           = -XD.3 } lXzXlXlXlXlXlXkXcXiXm   *.zXlXkXlXlXjXmX&Xy b .X+XoXoXoX",
"oXoXoX.X-XN.  G.FXgXlXjXVX`   @ <.^.g.8   k 0XbXkXlXcXfX@ c <Xh   X                                           ; XX2XI O gXcXlXlXlXlXlXkXcXiXM   *.zXlXkXlXlXgXFXD.  0.%XXXoXoXoX",
"oXoXoX X>X$X  ^ gXzXkXlXxXqXm     +     > W.mXjXlXhXBXn.  | tXd   X                                           : }.dX4.  M.BXhXlXlXlXlXkXvXuXl   @.xXlXkXlXkXxXgX!   J.*X.XoXoXoX",
"oXoXoXXX+XvX-.  T.CXgXlXkXbXtXu.Z t c ;.-XnXkXlXhXcXiX7 t +X,Xh   X                                           : .X5XeX0 9 pXcXhXlXlXlXlXcXpXQ ; 0.zXlXkXlXgXCXU.  :.:X XoXoXoXoX",
"oXoXoXXXoXVX@X, 8 1XNXgXzXkXxXMXVXZXCXNXvXlXlXhXlXbX]   d.sX=Xk   X                                           : oX<XGXt.  { nXlXhXlXlXlXlXzXNXZXmXlXlXzXgXBX,X6 < *X5X}.OXoXoXoX",
"oXoXoXXX@XhXVXB.  M 5XZXgXlXkXkXjXjXjXjXkXlXhXcXbX1.  / nX8X;Xk   X                                           : oX3XvXzX^   2.nXcXhXlXlXlXlXjXhXkXlXlXgXZX3Xm   V.SX%X.XoXoXoXoX",
"oXoXoXXX@XzXjXMXw.  g [.AXxXxXlXkXjXkXkXzXcXBXiX[   C tXnX7X;Xk   X                                           : oX3XvXxXtXV   [ iXBXcXzXkXkXjXkXlXxXxXAX].g   r.MXzX-X.XoXoXoXoX",
"oXoXoXXX@XlXkXkXxXc.. X o.7XkXvXMXVXNXnXlXfXn.7   / tXlXzX7X;Xx   @ O O O O O O O O O O O O O O O O O O O O   1 oX3XcXhXzXrX~   8 m.fXlXnXNXVXMXvXkX7XX.X X v.xXjXxX-X.XoXoXoXoX",
"oXoXoXXX@XvXvXcXvXCX].V $   B h.T. X/.V.{ @   t s.bXnXzXmX0X>Xy                                               . OX4XMXxXxXnXbXs.y   @ } C./. XT.h.B   # B [.CXvXxXMX-X XoXoXoXoX",
"oXoXoXXX@XeXwXeXwXqXaXiXi.H 9           * M O.*XjXwXwXwXtX1X@X@.J T Y Y Y Y Y Y U P L K K L P U Y Y Y Y Y Y I / }.:XtXwXeXwXwXjX&Xo.M ;           w J p.iXaXqXwXwXtX&XXXoXoXoXoX",
"oXoXoXoXOX].].].].].`.`.%X*XE.x.s.p.a.h.G.oX;X{._.].].].'. X X-X2X<X<X<X<X<X<X1X6XtXpXaXaXpXtX6X1X<X<X<X<X<X1X>X XXX'.].].].]._.}.;X|.b.7.<.>.2.e.J.&X&X`.'.].].].'.oX@XoXoXoXoX",
"oXoXoXXX@XaXpXpXpXiXpXgXdX5Xm._ F N A R 9.+XpXgXdXuXpXiXdX7X|.8XtXeXeXeXwXuXaXrXI.) z u u x _ I.rXaXuXwXeXeXrXwX.X,XdXiXpXpXpXpXiXrXuXjXvXnXnXnXcXfXtXtXpXpXpXpXiXdX*X.XoXoXoXoX",
"oXoXoXXX@XcXxXcXlXvXmX<X_ $ $ : ; & - > * + g W.zXNXlXzXnXrX'.sXbXxXzXzXNXiXi.< $ > 1 : : 1 > # 1 i.uXBXzXzXvXlX}.4XmXzXxXxXxXxXxXxXxXlXkXkXkXkXkXzXxXcXxXxXxXxXxXnX-X XoXoXoXoX",
"oXoXoXXX@XlXlXjXvXfX8.  # V 8.OXwXcXaX>XM.R 9   H >XMXhXcXwX].pXxXjXlXmXI.7   g X.!.6XkXkX6XQ...g   6 U.mXlXkXhX}.3XvXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX-X.XoXoXoXoX",
"oXoXoXXX@XzXkXbX0X(   N P.BXSXbXxXlXzXvXBXKX&Xo.  0 `.vXcXwX].pXzXlXkXf.  3 p.aXHXnXcXlXlXcXnXJXpXi.3   g.kXxXhX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX@XkXxXgXY   $.pXSXgXgXkXkXkXjXhXhXfXmXCXZ.; - oXVXqX].pXzXmXf.  N #XHXlXfXjXkXkXjXjXjXfXlXGX#XN   g.MXgX}.3XvXkXlXlXlXlXlXlXlXlXkXkXkXkXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX+XkXvX$.  :.cXbXfXlXlXlXkXmXBXBXvXkXhXhXZXT.= r wXtX'.iXNXI.  N 5XCXfXkXlXkXjXnXBXNXcXlXkXfXCX4XM   T.bX{.3XvXkXlXlXlXlXlXlXkXkXbXNXNXnXkXkXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXXXXSXI.  I kXcXjXlXlXlXjXcX2X$X&XwXcXkXkXgXSXj.  [ jX).fXiX5 3 #XVXgXlXlXkXlXNX5X%X&XuXzXlXlXfXCX@X3 9 eXXX3XvXkXlXlXlXlXlXjXcXbX9X>X>X5XbXcXkXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX.X%XiXI . *XBXjXlXlXlXhXNX$X>     e.HXfXlXlXjXVXV 1 P.oXfXp.  i.GXfXlXlXlXzXbXA.6     J.nXkXlXlXfXHXp.  e.+X3XvXkXlXlXlXlXkXcXhXd.a     0 4.pXxXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX X,X{.  4.bXkXlXlXlXkXkXcX(   #   s.FXfXlXlXkXbX}.  W ;XyX< g pXlXkXlXlXlXlX=.    $   U.nXkXlXlXkXzXiXh :  X3XvXkXlXlXlXlXkXbXi.    n n      .vXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX&Xw.  W.DXgXlXlXlXhXCXJ.  0 #   a.FXfXlXlXlXxXjXq f `.W.@ X.HXfXlXlXkXzXuX  t 4.;   U.nXkXlXlXlXfXHXX.O x.8XcXkXlXlXlXkXmX3X9   #.9XuX>.  o :XvXkXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX+X|.a M 7XcXjXlXlXkXvXwXc   m.q   a.FXfXlXlXlXlXzX6.  N.#.- !.nXjXlXlXkXxXqX .wX}.-   U.nXkXlXlXlXjXnXQ.: Q tXxXkXlXlXlXkXmX1XK C -XBXSX{.-   /.nXkXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X].  ) cXkXkXlXlXkXMXw.  C dX9   a.FXfXlXlXlXkXmXJ.  d.K > 7XcXkXlXlXlXlXjXlXFX^.=   U.nXkXlXlXlXkXcX5X1 z iXzXkXlXlXlXlXlXzXcXvXlXdXAXx.  @ <XvXkXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X'.   .FXgXlXlXkXvX*X&   J.KX<   a.FXfXlXlXlXjXBX[.  p.B * lXlXlXlXlXlXlXlXhXVX/.=   U.nXkXlXlXlXlXlXlX> p pXzXkXlXlXlXlXlXlXlXlXhXNX+Xy   ..vXzXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X'.   .DXgXlXlXjXMXT   / bXbX4   a.GXfXlXlXlXjXBX[.  p.B * kXlXlXlXlXlXlXlXhXCX/.=   U.nXkXlXlXlXlXlXkX> p pXzXkXlXlXlXlXlXlXlXjXNX*Xf   c 0XvXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X].  ( xXkXkXhXVXC.  2 $XVXMX5   d.KXgXlXlXlXkXmXJ.  d.K > 6XcXkXlXlXlXlXlXhXCX/.=   U.nXkXlXlXlXkXcX4X2 z iXzXkXlXlXlXlXlXlXjXNX@Xi   h -XcXhXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX+X Xs M 7XcXjXfXGXG   . & # & . X   b 8XbXkXlXlXzX5.  N.$.; !.nXjXlXlXlXlXlXhXCX/.=   U.nXkXlXlXlXjXnXE.: Q tXxXkXlXlXlXlXlXkXNX Xw   n 3XCXxXxXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX&Xe.  W.DXgXgXAX[ - q 4 5 2 X   . H 9XbXkXlXxXjX9 g `.Q.@ ..JXfXlXlXlXlXlXhXCX/.=   U.nXkXlXlXlXfXJX .O c.8XcXkXlXlXlXlXkXcX(.6   e '.rX4X6XpXzXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX X,X{.  3.bXkXkXcX,XXX@X+X@X|.2   +.qXaXzXlXkXbX}.  Q ;XyX1 g pXzXkXlXlXlXlXhXCX(.:   Y.nXkXlXlXkXzXiXh :  X3XvXkXlXlXlXkXnX7Xu   + t Z b m v S.nXkXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX.X%XiXI   *XBXjXlXbXmXmXmXmXcX$   a.IXgXlXkXjXBXN 1 I.oXfXa.  i.GXfXlXlXlXlXhXZX!.    K.nXkXlXlXfXGXy.  r.+X3XvXkXlXlXlXjXNX&X                0.NXjXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXXXXSXU.  P kXvXjXkXhXjXhXjXhX-X%XqXzXkXkXgXSXf.  } jX).fXiX7 2 @XCXfXlXlXlXlXxXpX=X&XiXzXlXlXgXCXOX1 q eXXX3XvXkXlXlXlXlXzXgX;X&X*X=X-X-X-X-XrXzXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX+XkXbX%.  ;.cXbXfXlXlXlXlXlXNXBXvXkXhXhXZXU.* y eXtX'.iXBXY.  M 4XCXfXkXlXlXlXxXNXBXcXlXkXfXCX3Xn   R.bX{.3XvXkXlXlXlXlXlXzXNXBXNXNXNXNXNXBXvXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX@XkXxXgXT   #.iXSXgXgXkXkXlXjXhXhXfXmXVXV.- ; OXVXqX].pXzXmXg.  M @XGXzXfXjXkXkXjXjXjXfXzXGX+Xm   h.NXgX}.3XvXkXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX@XzXkXvX0X)   m K.NXSXbXxXlXzXvXBXJX&X..  q '.vXcXwX].pXzXlXkXg.  1 u.iXHXnXcXlXlXcXnXJXiXu.1   h.kXxXgX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX-X.XoXoXoXoX",
"oXoXoXXX@XxXzXkXnXhXq.  # V 7.XXwXvXaX:Xm.R 9   L ,XNXjXvXeX].aXvXkXxXMXT.0   h ..W.5XlXlX5XW...h   9 R.NXxXzXkX}.4XbXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXbX-X XoXoXoXoX",
"oXoXoXXX#XsXsXsXpXdXjX%XW   X = ; & = ; @   y L.pXkXiXaXgX9X{.uXlXhXhXgXbXeXr.; o * : * * : * o : t.eXbXgXgXkXfX|.2XxXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXzX=X.XoXoXoXoX",
"oXoXoXoXXX1X1X1X1X<X1X6X8X=Xz.) F N Z T 5.{.6X7X3X,X1X<X2X*XXX.X}.}.}.}.{.XXXX[.n.| H B B H | m.[.XXoX{.}.}.}.|.@XXX}.|.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.|.}.OX+XoXoXoXoX",
"oXoXoX+X).:.>.>.>.>.>.:.>.,.6.w.r.t.r.e.8.1.>.:.>.>.>.<.*.h.@X>X4X3X3X3X3X,XqXdX&XA.g.p.p.g.S.&XdXqX,X3X3X3X4X2XXX*X5X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X5X$XoXoXoXoXoX",
"oXoXoX#X(.                                                S 2XyXmXvXvXcXmXGX{.o.N +         + N o.{.GXmXcXvXbXxX}.5XNXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXMX-X XoXoXoXoX",
"oXoXoX#X(.X + + + + + + + + + + + + + + + + + + + + + $   E <XwXzXjXjXnX6X) :   9 7.K.[.[.K.6.8   ; ( 8XnXjXlXhX|.3XcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXxX=X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XeXxXjXbXoXt   C .XkXxXmXBXBXmXxXkX XV   t OXvXkXhX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XeXlXMX`.- = j.VXbXxXlXkXjXjXkXlXxXbXVXj.- - `.NXfX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XqXMX;X9 : T.SXjXkXjXhXjXjXjXhXhXkXkXjXSXT.; 9 ,XvX{.3XvXkXlXlXlXlXlXlXlXkXjXjXjXjXkXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XyXzXF   A.ZXgXlXlXBXZXZXZXZXZXZXmXkXlXgXAXZ.  L gX.X3XvXkXlXlXlXlXlXlXlXbXBXZXZXBXnXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XpXQ.  o.CXhXjXlXhXE 4 e 0 0 0 6 u.ZXhXkXhXCXO.  U.OX3XvXkXlXlXlXlXlXkXmXOX| d p ~ _.bXkXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XpXg 9 *XmXhXkXxXqXy   O # # # o 7.SXgXlXhXmX&X0 a OX3XvXkXlXlXlXlXjXNXW.;   @ O     c.nXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   U 4X.X+ R KXfXlXjXbX;Xe   h.(.Q.~.^.<XvXkXlXlXfXJXE X K.6XvXkXlXlXlXkXvXeXn   n E.).D   > wXcXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   P eX=.- N.NXjXlXhXMX|.1 O 8XUXUXIXCXcXlXlXlXlXhXBXM.* X.eXxXkXlXlXlXjXMX;X9 $ _.SXJX).$   ).nXkXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   L iXN 1 ,XcXkXlXhXVXE.* ; E.E N +.=XbXkXlXlXlXkXvX:X1 m iXzXkXlXlXlXlXxXdX&X&XsXdXZXP.o   +XbXkXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   L aXa , sXzXlXlXgXSXB.    ; O     9 .XmXjXlXlXlXzXaX, s pXzXkXlXlXlXlXlXxXNXNXjXcXiXI   N hXxXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   K aXy ; cXlXlXlXhXBX(.D h w.-XS.8   G mXjXkXlXlXlXcX: i pXzXkXlXlXlXlXlXlXjXgXcXdX{   = }.nXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   L pXg < wXxXkXlXlXjXBXIXcXVXzXLXi.  9 $XnXjXlXkXxXqX1 h pXzXkXlXlXlXlXlXlXjXbXaX'   # H.mXkXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   L uXK < OXbXkXlXkXcX1X'.;XlXhXbXU.  4 |.MXhXlXkXbXXX, F uXzXkXlXlXlXlXlXjXnXiX!   & F.MXkXkXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   I 9Xh.& 8.SXgXlXfXHX0.  j eXvXZX+.  s wXxXjXlXgXSX6.# 0.0XcXkXlXlXlXlXjXvXwXI   - K.CXzXxXzXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y 2X4X$ V BXgXlXhXBX).&   h a.[     5.SXgXlXlXgXNXV + ).4XvXkXlXlXlXkXcXuXT   @ v 4.:.:.:.`.vXkXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XaX' @ K.SXfXlXhXVXB.r       ; $.jXlXlXlXfXSXJ.@ / +X3XvXkXlXlXlXjXBX%X                7.NXjXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XpX1X  M iXbXhXlXjXZX:Xv.t.d._.NXzXlXlXhXbXuXn   -XOX3XvXkXlXlXlXkXvXeXy.8.9.9.0.0.0.9.}.vXkXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XeXmX9.  $.cXvXjXlXhXbXFXKXHXBXhXkXlXjXvXcX+.  w.cX}.3XvXkXlXlXlXlXkXcXKXLXLXLXLXLXLXLXNXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XwXvXgX)   ;.kXBXkXgXgXfXfXfXgXjXgXkXBXjX=.  _ jXkX{.3XvXkXlXlXlXlXlXkXfXfXfXfXfXfXfXfXjXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XeXlXvX0XT   L &XbXDXvXkXgXgXkXvXDXbX&XK   R qXnXfX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.. O O O O O O O O O O O O O O O O O O O O O #   R <XeXxXhXvXfX%.    2.R.6XzXDXDXzX5XR.2.    &.gXcXjXhX|.3XcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX-X.XoXoXoXoX",
"oXoXoX#X(.                                                F 2XtXnXcXxXbXNXE.R     m /  . ./ n     R E.NXbXxXbXzX}.5XMXxXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXmX-X XoXoXoXoX",
"oXoXoXOX_.n.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.M.v.G.oX*X-X-X-X*X*X8XXXB.%.e         e &.V.XX8X*X*X-X-X=XOX$X-X=X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X@XOXoXoXoXoX",
"oXoXoXoXOX;X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X;X%XoXXX X.X.X.X X{.OX=X@X}.].'.'.].}.#X=XOX{. X.X.X X.X+XoX X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X XOX].oXoXoXoX",
"oXoXoXoXoX.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.XXXoXoXoXoXoXoXoXoXXX.XoX@X#X#X#X#X@XoX.XXXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX.X.XXXXXXXXX.X.XoXoXoXoXoXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoXoXoXoXoXoXXX X.XXXXXXX.X XXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXOXXXXXXX.X|.=X>X*X*X*X*X>X=X|..XXXXXXXoX$X#X$X$X$X$X$X$X$X$X$X$X$X$X#X$XoXXXXXXXXX|.oX>X;X&X*X&X-X,X+X|.XXXXXXOXoXoXoXoX",
"oXoXoXoXXXyXfXpXhXMX|.<.h < < j <.|.MXhXpXsX8X ., e 0 0 0 0 0 0 0 0 0 0 0 0 e ,  .8XsXsXpXnXaXZ.! 0 > 7 P c.wXMXpXdXyXoXoXoXoXoX",
"oXoXoXoXXXfXzXNXiX` - c e.Z.Z.e.c = ` iXNXjXrXT                                 T rXzXkXSXQ.s < _ c.D.n.X.5 9 B.ZXcXdXXXoXoXoXoX",
"oXoXoXoXXXpXNX<Xt g  XCXBXVXVXBXCX|.g t <XmX0X!   + X X X X X X X X X X X X +   ! eXhXBXd.X -.aXZXCXCXBXCXkXy.@ -.NXsX.XoXoXoXoX",
"oXoXoXoX.XhXuXt E mXCXfXxXVXVXzXfXCXmXR t yXyXW   o                         o   Q qXVXB.o P.KXcXgXhXBXCXlXlXJXoX& 0.bX XoXoXoXoX",
"oXoXoXoX|.MX` g mXcXfXBXwXQ.!.tXMXfXcXmXg ) kXR   o                         o   E iX5X# c.JXfXjXnXbX(.T.yXxXdXFX^.o _.=X.XoXoXoX",
"oXoXoX.X=X|.-  XVXdXNXI.>     7 [.NXdXCX|.& (.]   o                         o   T xX| N VXjXkXxXwXY     }.MXjXgXFX] M ;X.XoXoXoX",
"oXoXoX.X>X,.c CXgXxXdXi 8  X).  C bXkXhXVXl >.|   o                         o   ~ 7Xq M.DXgXhXFX-.1 L . XXMXjXhXVX].; E.#XXXoXoX",
"oXoXoXXX*Xh r.CXjXzXhX,XyXPX8X, P nXkXhXCX8.N ]   o                         o   { K.7 3XbXkXkXnX(.iX6.  oXMXjXkXxXaXd 5.,X XoXoX",
"oXoXoXXX*X< A.AXhXlXlXnXiXh   r 4XMXjXhXAXB.y ]   o                         o    .n.2 zXlXlXlXkXbXHX%.  oXMXjXlXjXZXx +.2X XoXoX",
"oXoXoXXX*X< Z.AXhXlXzXCXjXv...= o.lXlXhXAXB.y ]   o                         o    .n.2 zXlXlXlXlXfXZX=.  oXMXjXlXjXZXx +.2X XoXoX",
"oXoXoXXX*Xh e.CXhXcXiXH.>XUXUXW   <XMXgXVX8.B ]   o                         o   { L.7 2XbXkXlXlXhXAX*.  oXMXjXkXxXpXd 5.,X XoXoX",
"oXoXoX.X>X<.c CXgXnX9XO 9 `.W.> > wXbXgXVXk ,.|   o                         o   ~ 7Xw m.DXgXlXlXhXAX-.  OXMXjXhXVX].; W.#XXXoXoX",
"oXoXoX.X=X|.= |.VXdXMXA.*     , K.NXdXCX}.& (.]   o                         o   T xX .M VXjXkXlXhXSXo.   XNXjXgXFX' M ;X.XoXoXoX",
"oXoXoXoX|.MX' g mXcXgXBX7XQ.~.qXBXfXcXnXd _ kXR   o                         o   E iX5X$ x.JXfXkXkXvX*XU.yXxXdXFX!.X `.*X.XoXoXoX",
"oXoXoXoX.XhXiXt R mXCXfXcXVXVXxXfXCXnXY y uXyXW   o                         o   Q qXVXV.o P.KXxXhXhXbXCXlXlXJX.X% w.nX XoXoXoXoX",
"oXoXoXoXXXpXNX<Xt f }.VXBXVXVXBXVX}.d y <XnX0X~   @ o o o o o o o o o o o o @   ! wXhXBXd.X *.iXZXZXZXBXCXkXr.+ ;.NXaX.XoXoXoXoX",
"oXoXoXoXXXhXcXVXsX[ ; x 9.B.B.9.x ; [ sXVXzXtXI                                 I tXcXzXFX^.f 1 ) c.F.m.X.6 w Z.SXbXgXXXoXoXoXoX",
"oXoXoXoXOX&X=X%X;X5XG.@.N p p N #.G.5X;X%X*X%XZ.u.d.s.p.a.k.B.S.D.A.b.g.i.a.d.u.Z.&X*X*X%X6X&Xt.G 5 = 2 B 6.XX8X%X*X*XOXoXoXoXoX",
"oXoXoXoXoX4X8X6X5XiXiX(.@.T T #.(.iXiX5X6X9X#X5XhXaXiXcXxX%X9./ W } Z.eXmXgXiXhX5X#X9X7X7X4X8XsXaXuXiXuXpXdX0X4X7X8X4XoXoXoXoXoX",
"oXoXoXoXXXhXvXnXCXG.i < G ~ ~ G < i G.ZXbXmX-X7XbXjXAXoXF & n W ! I w , 5.gXMXxX8X=XMXcXvXvXcXzXxXcXcXcXxXzXcXvXvXnXhXXXoXoXoXoX",
"oXoXoXoXXXaXcXkX' O 9.4XcXGXFXcX4X8.O ] kXbX&X7XxXNXl.X ^ #XjXSXHXMXtXS.7 f 2XVX4X=XcXkXkXkXkXkXkXkXjXkXkXkXkXkXkXzXsXXXoXoXoXoX",
"oXoXoXoXXXsXNX! 8 >XGXbXlXhXlXcXbXGX>X7 ! VX*X4XFXl.X D.GXMXlXgXlXzXvXAXlXY 9 tXwX&XvXkXlXlXlXlXjXxXcXzXjXlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXoX}.NXt.- 6XCXfXkXkXzXyXiXjXfXCX6X- p.7XrX@XX F.JXgXhXvXMXyXiXkXgXvXBXV H yX&XvXkXlXlXlXlXBXjXpXzXNXkXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX#X2X3 N.GXfXlXhXZX2.  x fXxXdXGXN.4 ).sXH ~ GXgXkXxXaX .  n dXxXgXMX4X< k.6XzXkXlXlXkXmXv.9 O d W.mXjXlXlXxXsXXXoXoXoXoX",
"oXoXoX X,Xa.w bXkXlXjXNX.X+   t fXxXkXkXvXw 2.&X& #XMXjXjXBXD + * u dXzXkXgXHX| c 9XzXkXlXhXVXU.  V v.7 o 2XnXjXlXxXsXXXoXoXoXoX",
"oXoXoXXX=XZ ;.CXjXlXkXnXc v M 5 hXxXkXjXCX&.H 5.m jXzXkXlXkX5.;Xc t fXzXkXjXVXT.5 |.mXjXlXhXZXM.C 7XUXB.  I.CXjXlXxXsXXXoXoXoXoX",
"oXoXoXXX&X4 B.AXhXhXAXm.  {.I < fXxXkXhXAXb.d W ! SXhXlXlXjXNXnXa y fXzXkXkXbX5X& Q.BXjXlXlXkXvXMXlXNX~   >XmXjXlXxXsXXXoXoXoXoX",
"oXoXoXXX*X> S.SXgXvXrX> / UXA 5 VXcXkXhXSXC.i Y ^ JXgXlXlXlXlXjXd t fXzXkXkXvXwX# W.VXjXlXlXlXjXjXVX2.  r.BXjXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX*Xr j.CXfXAX@.  i.}.s ; ~.hXzXhXCXs.z ' Y NXkXlXlXkXzXlXd t fXzXkXkXnX&X; ^.BXjXlXlXkXxXNX:.  1.BXzXkXlXlXxXsXXXoXoXoXoX",
"oXoXoX.X;X{ U ZXfXCXG   o   O   0 eXvXgXZXP ` Z.e tXvXkXlXlXzXlXh p fXzXkXgXFXg.e -XvXkXlXlXlXxX-.  ;.mXgXjXlXlXlXxXsXXXoXoXoXoX",
"oXoXoX X:XI.; 9XvXlX<XOX#X2Xe   *XlXjXbX8X: k.wX< S.AXgXlXkXzXlX6 < fXxXkXjXBXB ! eXlXkXlXgXDXp.    w e < b.VXjXlXxXsXXXoXoXoXoX",
"oXoXoXoX.XkXn ( HXgXvXMXnXSXa.3.bXlXgXHX/ M ;XsX9.7 lXvXhXlXzXlX0.7.hXlXdXHXC.-  X,XxXkXlXjXBXU. .#.[ } ) !.mXjXlXxXsXXXoXoXoXoX",
"oXoXoXoX XcX+X# f.JXzXdXhXgXAXSXdXxXJXs.# $X2X7XkXd U BXMXgXhXkXSXSXhXjXHXoX# j.aX%XvXkXlXlXjXBXKXHXKXLXPXNXkXlXlXxXsXXXoXoXoXoX",
"oXoXoXoXXXiXAXJ.o =.hXHXMXbXzXvXHXhX*.O J.DX$X5XVX2X9 V 3XHXVXbXlXxXFXBXC.# &.AX5X*XcXkXkXkXlXhXfXfXfXfXfXhXkXkXkXzXsXXXoXoXoXoX",
"oXoXoXoXXXdXlXCX'.9 e ,.'.7X7X'.,.e 9 ].CXxX*X0XnXVXtXH < } U.2X9X#Xf.B - h.AXMX8X=XMXcXvXvXvXvXvXvXvXvXvXvXvXvXvXnXhXXXoXoXoXoX",
"oXoXoXoXXXyXfXiXcXiX0.m t 4 4 r m 0.iXcXiXgX=X;X0X4XwXyXh.x t 7 4 0 p E }.aX5X8X:X$X9X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X4XoXoXoXoXoX",
"oXoXoXoXXXl.p.d.p.d.B.c.2.=.=.2.c.B.d.p.d.u.E.=X*X=X$X=XsXuXz.$.O.,._.zX8X#X&X=X$X@X=X*X*X*X*X*X*X*X*X*X*X*X*X*X*X=X&XOXoXoXoXoX",
"oXoXoXXX$X<                                 u.gXbXlXCXzXu.s y t e y r G {.SXvXmX9X=XMXcXvXvXvXvXvXvXvXvXvXvXvXvXcXnXhXXXoXoXoXoX",
"oXoXoXXX#Xe   O o o o X X . . X X o o o @   d.sXhXMX$Xr 0 e.@XfXxXwXY._ o @.xXbX5X*XcXkXkXkXkXkXkXkXkXkXkXkXkXkXkXzXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   s.iXVX.X* { hXFXvXhXgXkXVXFX X5 T NX7X*XvXkXlXlXlXlXjXhXgXhXkXlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   a.jXeX4 $.GXxXxXSXFXGXHXBXfXAX9X1 <.sX%XvXkXlXlXlXkXmXDXGXSXvXkXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   p.nX+.f NXjXmXE.m B M j :.nXdXSX^.* Q.1XxXkXlXlXjXNX#X] M =.7XnXkXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   h.7X= Q.CXdXZX8.  M H m 4.nXkXhXSXL J eXlXkXlXjXnX%X# * L   a iXcXkXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   m.z.a pXcXhXCX$.< nXHXGXBXkXlXhXSXm.0 $XnXjXlXhXDXp.o }.UXp.  E.VXjXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   A.' T CXjXjXBXI @ ] 2 ~ 4XbXkXkXnX:X= ~.BXjXlXlXxXyX7XhXHX6.  |.NXjXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   D.E ! JXgXjXmX#.< #.-.  B cXkXkXvXeX# W.VXjXlXlXlXcXxXAXE.  Q nXlXkXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   S.) R ZXjXlXkXCXcXNXKXO.  %XMXhXbX1X* !.BXjXlXlXlXhXCXU.  v iXcXkXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   M.p.k dXxXkXcX$.2.mXHX}   :XnXgXZXD.7 OXnXjXlXlXjXVXH.  H vXFXcXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   j.<X& [.BXfXVX}   E |   Q MXjXgXFX~ V wXlXkXlXhXVXK.    ! #.) ~.mXjXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   p.bX^ Z SXhXzXlXw.u w >.pXcXfXCX+X= D.4XxXkXlXhXSXs.4 s 7 5 ; c.VXjXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   p.zX<X& u.KXjXjXBXNXNXVXzXdXNXhXu [ aX%XvXkXlXlXkXvXmXbXmXMXNXvXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$Xw   o X X X X X X X X X X X X O   d.iXCXU.X q.BXZXxXhXgXjXmXFX7Xh c lX9X&XcXkXlXlXlXkXkXkXkXkXkXkXlXlXkXzXsXXXoXoXoXoX",
"oXoXoXXX$X5                                 p.fXlXCX!.: b L.0XNXSXlX&X0.& U sXBX6X=XnXzXxXxXxXxXxXxXxXxXxXxXxXxXzXcXfXXXoXoXoXoX",
"oXoXoXoX@Xn 5 w 0 0 0 0 0 0 0 0 0 0 0 0 e < l.yXdXiXbX2X] = y z x j 3 w v.lXhXfX4X&XhXsXsXsXsXsXsXsXsXsXsXsXsXsXsXfXyXoXoXoXoXoX",
"oXoXoXoX.X@X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$XXXoXXXXX|.#X>X{.u.#.o.;.A.&X;XXX XXXoXOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoX.XXXoXoXoX",
"oXoXoXoXOXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoXoXoXoXoXXX.X+X:X2X3X1X&XXX.XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXX.X X X X.XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXOXOXOXoX.X X X.XoXOXOXOXXX|. X X X X X X X X X X XoXOXOXOXoX.X X X.XoXOXOXOXoXoXoXoXoX",
"oXoXoXoXXX|.|.{.@X>X3X2X;XXX{. X|.$X1X,X<X<X<X<X<X<X<X<X<X>XXX|. X{.XX;X2X3X>X@X{.|. XoXoXoXoXoX",
"oXoXoXXX;X6X6XdX|.5.) ] s.:XsX3X8XA.} +.O.O.O.O.O.O.O.O.X.&.OX8X3XsX:Xs.] ) 5.|.dX7X4X@XXXoXoXoX",
"oXoXOX|.6XBXbX,.m *.g.a.{ b M.DXmX4.                      . $XnXDXM.b { s.f.*.n ,.mXbX#XXXoXoXoX",
"oXoXOX|.6XbXU } sXFXUXUXAX,XN 6.GX8.  @ o o o o o o o O   < +XFX6.N <XAXHXUXHXsX} Y xX$X.XoXoXoX",
"oXoXOX{.dX,.} PXMXjX/.oXcXVXcXv R.d.  o               .   = 3XY.v bXMXnXiX/.qXbXPX} -.6X|.oXoXoX",
"oXoXoX@X|.m sXnX9Xh e 5 3.vXCX_.H u.  o               .   ; :XG `.CXxX*Xp   U.BXlXfXx E.$XXXoXoX",
"oXoX.X>X5.=.SXcX=X2.SXf.3 zXlXkXQ `   X               .   6 C.I xXhXVXI.u.0 K.ZXdXFX&.,.,X XoXoX",
"oXoX X3X) j.FXfXbXKX+.X x.ZXdXZX@.S   .               .   w w.' DXhXjXMXxX< L.ZXdXFXj.) 3X XoXoX",
"oXoX X2X] d.DXjXdXgX3X4.p rXzXBXo.G   .               .   w t.` ZXhXkXcXtX1 L.ZXdXDXs.' 2X XoXoX",
"oXoX.X;Xs.{ ZXMXE.e -Xk.  4XmXaXL +.  X               .   3 Y.F fXzXkXcXuX- J.AXsXDX` w.:X.XoXoX",
"oXoXoXXX:Xb >XCXiX| 6 w m.zXJXn.^ f.  o               .   = 4X~ m.LXsXcXiXp R.mXMX,Xz |.+XoXoXoX",
"oXoXOX{.sXM.M cXFXCXpXhXVXKX=Xp :Xi.  + X X X X X X X o   : >X-Xp -XKXzXhXpXhXAXcXM b.5X|.oXoXoX",
"oXoXOX|.5XHX0.m '.kXSXCXaXB.f W.KX4.                      $ +XJXE.f V.hXAXHXvX].n w.SX@XXXoXoXoX",
"oXoXOX.X<XiXxXN.b R $.+.F G {.zXiXa.4 u w t k n n k t e q k @XuXzX|.G n ~ / S v C.cXtX#XXXoXoXoX",
"oXoXoXXX*X,X-XlX1X%.k b i.pXaX=X;X%X7X3XaX6XV.1.1.V.6XaX4X3X#X<X;X7XeX].M.b.W.7XwX:X,X@XoXoXoXoX",
"oXoXOX|.7XmXZXg.m | q.7.Q C ~.KXuX<XvXSXD.N Q ;.-.W M S.FXdX:XbXcXzXzXMXAXSXVXxXzXvXcX$XXXoXoXoX",
"oXoXOX|.5XCX .K 1XBXGXLXNX(.g n.cX*XDX6.n #XMXHXUXVX+Xn 8.mX=XzXkXkXkXgXcXcXgXkXkXlXkX$XXXoXoXoX",
"oXoXOX[.dXu.U FXmXkXsX:XaXGXtXk Y.hXA.m bXBXmXgX:XsXZXvXN M.qXkXlXlXzXVX6X6XNXzXlXlXkX$XXXoXoXoX",
"oXoXoXOX#Xb wXnXdXZX_   '.nXSXT.B qXM @XBXxX%Xa X #XvXBX$Xl :XxXkXkXnX,.4 4 3.mXkXlXkX$XXXoXoXoX",
"oXoX.X:Xw.+.DXsXAXL.6 - W.CXhXjXP 4._ NXdXZXk.+.1 XXNXfXVXU N.CXhXbX0Xp [.`.  3XnXkXkX$XXXoXoXoX",
"oXoX X2X_ h.DXkXlXt C.p R.AXdXCX$.x q.DXhXjXNX8X* oXNXfXGX-.6.GXhXlXjXfXUXg.6 dXxXkXkX$XXXoXoXoX",
"oXoX X2X_ g.AXCX-.l fX, K.VXfXCX$.x 0.DXhXjXMX=X= oXNXfXGX-.6.GXhXlXkXHXV.@ ].CXhXlXkX$XXXoXoXoX",
"oXoX.X:Xe.+.SXxXM 3 a   g yXcXhXL 4._ NXhXjXmX;X& oXNXfXVXU N.CXjXjXmXn.  S.zXdXzXlXkX$XXXoXoXoX",
"oXoXoXOX$Xb qXnX6X2X*X> V.vXDXY.B qXM +XCXdXMX;X; OXvXBX#Xl :XxXjXbX8X% % f q +XMXjXkX$XXXoXoXoX",
"oXoXOX{.dXu.I DXCXcXxX2XfXHXrXj T.gXS.n bXCXjXsX<XaXZXcXm M.qXkXkXzXgX4X1X=X:XsXzXlXkX$XXXoXoXoX",
"oXoXOX|.4XCX .J ,XNXSXKXMX/.f n.xX=XHX8.M $XBXFXLXVX#XM q.NX=XcXzXzXxXMXMXNXNXcXzXxXzX$XXXoXoXoX",
"oXoXOX|.8XBXSXx.B } 8.3.W F _.PXpX:XfXmXn.k ~ 0.9.~ k n.NXtX-XfXdXdXdXaXaXaXaXdXdXdXsX#XXXoXoXoX",
"oXoXXX@XT.x.n.L.z.] A G $.C.H.x.Z.$X:X%XdX8X3.z z 3.9XdX%X-X#X:X;X;X;X;X;X;X;X;X;X;X;X+XoXoXoXoX",
"oXoX|.<X|         o $ # .       7 7XzXSX`.P E #.#.E P _.GXaX:XcXzXxXxXxXzXzXxXxXzXxXzX$XXXoXoXoX",
"oXoX X<X+.  + X .         X O   y 3XDXc.g U.kXSXSXkXI.g b.MX*XzXkXlXlXhXzXzXhXlXlXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   w iX^.h yXGXdXtXrXsXGXyXk Y.9XkXlXlXlXVXhXhXVXlXlXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   r qXA (.HXeXk 9 8 ' zXSX`.b 2XzXkXjXMXj.e w l.MXjXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   h G.U mXvX2X7 ~.1XwXlXhXNXH S.VXhXvXqX4 S.D.X 6XbXkXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   n 3.-.SXnXoX  Y f K.BXfXGX*.8.GXhXzXgX6XUXK.: uXcXkXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   n <.>.GXjXpXK.%Xe.; yXlXGX;.5.HXhXlXkXKX/.X S.ZXhXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   l v.( BXbX*X-.ZX(.% 9XxXVXQ c.ZXjXjXMX!.% n.GXjXlXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   u <Xn ,XVXqXh w 3 6.mXnX2Xj %XcXjXvXqXO   n s @XMXjXkX$XXXoXoXoX",
"oXoX X<XO.  O               X   w dXj.J SXCXjX/.+XbXnXDXK i.wXjXkXxXsX|.[.Q.~.yXxXlXkX$XXXoXoXoX",
"oXoX X<XO.  X               .   r 5XZXX.U qXFXUXUXSXwXI +.bX-XxXlXlXxXVXCXZXAXcXlXzXlX$XXXoXoXoX",
"oXoX X,X+.  @ o o o o o o o +   u 5XxXMXr.l ..d.d.X.l r.VXsX;XzXkXkXkXhXhXhXhXkXkXlXkX$XXXoXoXoX",
"oXoXoXOX_.T.E.R.R.R.R.R.R.R.E.R.Q.+X#X#X6X).5._ _ 5._.6X#X#X@X$X$X$X$X$X$X$X$X$X$X$X$XoXXXoXoXoX",
"oXoXoXoX@X%X$X$X$X$X$X$X$X$X$X$X#XoXXXXX|.@X>X2X2X>X@X|.XXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXoXoXoXoX",
"oXoXoXoXXXXXXXXXXXXXXXXXXXXXXXXXXXoXoXoXoXXX.X X X.XXXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXOXOXoX.X X X.XXXOXOXOX.X X X X X X X X X X|.XXOXOXOXXX.X X X.XoXOXOXoXoXoXoXoX",
"oXoXoXoX.X X{.oX>X<X<X,X$X{.|. X-X<X,X,X,X,X,X,X,X,X<X$X|.|.{.$X,X<X<X>XoX{. XXXoXoXoXoX",
"oXoXoX.X,X8XdX<Xy.) Q ;.`.gX0X2X:.W ) / / / / / / ) R B.eX8XhX`.;.Q ) y.<XdX7X%XXXoXoXoX",
"oXoXOX X8XKXW.S <.K.T.d.J 7.ZXsXi                     5.VXBX7.K f.R.K.1.A Q.HX%X.XoXoXoX",
"oXoXOX{.dXW.N 1XUXUXUXUXbX..*.xXx   @ o o o o o o @   9.HX$.X.nXHXUXUXJX2XN E.7X}.OXoXoX",
"oXoXoXoX<XS 1XHX1X@.^  XMXDXE A.S   X             o   g.!.Y GXxXsX3.:.fXSX2XZ XXOXoXoXoX",
"oXoX.X>Xy.1.GXnX .} r.3 uXAX).~ S   X             o   f...(.NXBXk.5 r jXfXJX,.5.,X.XoXoX",
"oXoX X<X( U.ZXgXfX>X` / vXzXtXW h   X             o   2.^ tXxXkXdXE.s kXkXZXI.( <X XoXoX",
"oXoX X<XQ Q.ZXfXFX&XW L uXvXaXW d   X             o   ,.~ aXzXhXGXI.u kXkXCXQ.! <X XoXoX",
"oXoX.X,X;.f.FXxX] H.2X   XFX%XE M   X             o   t.` &XmXgXZXL.w kXhXFXs.#.<X XoXoX",
"oXoXXX$X`.J vXBXB.i t 4.jXIX<.8.H   X             o   l.h.>.UXpXVXW.m gXxXbXG I.%XXXoXoX",
"oXoXOX{.gX7...FXUXcXdXGXUXH.F yXb   @ o o o o o o @   e.vXA J.UXmXkXhXCXFX .6.9X}.oXoXoX",
"oXoXOX|.qXDX;.W /.uXgX%X<.J eXlXu                     3.HX9XJ 3.;XgXaX'.Q :.AX=X.XoXoXoX",
"oXoXoXXX;X7XtXB._ T U ! 9.2XwX,X1.^ _ +.&.o.o.&.+.` ! C.7XwX4X-.F F F K x.iX6X#XXXoXoXoX",
"oXoXoX.X1XwXhX&X1.S N { R.gXuX;XyXnXFX}.;./ / ;.}.DXnX1X7XeXrXcXaX6X9XkXkXqXeX%XXXoXoXoX",
"oXoXOX|.9XJXj.Z c.*X,XT.^ ' vX0XqXBX-.K A.$X%XA.K ;.BX<XdXbXxXlXlXcXxXlXzXcXbX=X.XoXoXoX",
"oXoXOX{.gXv.I zXFXCXHXDXJXt.( 0XjX,.o.ZXHXLXDXFXZXo.<.tXyXzXkXkXCXBXZXvXkXkXzX=X.XoXoXoX",
"oXoXoX+X@XS sXbXbX+Xu K.MXKX..f.[.L ZXxXpX@.V 9XvXCXU Z.cXlXjXnXx.c ` wXvXkXzX=X.XoXoXoX",
"oXoX.X,X5.e.HXdXbXL   f.SXnXXX^ #.D.ZXMXU.A 1 2XxXAXF.( MXhXnX,Xq /.S | GXgXzX=X.XoXoXoX",
"oXoX X<X~ E.NXFXa.[ ` u.JXjXpXT V ,XnXjXxX5X0 3XbXnX;XK zXlXzXaXuXUXV 3.FXhXzX=X.XoXoXoX",
"oXoX X<X~ T.GX5X= ~.P ;.VXlXpXT V >XnXhXNX=X8 4XbXnX-XK zXlXjXvXGX` I VXlXkXzX=X.XoXoXoX",
"oXoX.X,X6.0.UX(.s F . q 9XZX.X^ #.D.DXfXMX*X- 2XxXSXF.) MXjXlXlXU * ^.;XzXkXzX=X.XoXoXoX",
"oXoXoX+X#XS aXMXsXNX$.n.VXKX .f.{.L ZXkXxX2XU 5XbXCXI A.cXjXmX>Xk J x 2.MXjXzX=X.XoXoXoX",
"oXoXOX{.gXv.P lXGXmXAXGXHXe.( 0XjX<.X.ZXSXMXSXFXCXX.<.tXyXzXkXzXVXmXMXnXkXkXzX=X.XoXoXoX",
"oXoXOX X9XJXk.D b.&X:XT._ [ bX0XrXAX,.K S.>X;XS.K <.AX2XsXbXcXcXzXzXzXxXcXcXvX=X.XoXoXoX",
"oXoXoXXX&X,XrXR.[ J G Q h.0X4X$X-X1XrXW.| V V  .W.rX<X%X>X1X1X1X1X1X1X1X1X1X1X#XXXoXoXoX",
"oXoX X>X..% 3 q s r w p u 4 $ +.sXsXgXN.{ Y Y { N.gXhX;XeXsXpXaXpXpXpXpXpXpXsX&X.XoXoXoX",
"oXoX X<X~                     ( MXjX^ | oXfXfXoX} / xX4XaXvXxXxXlXbXxXlXxXxXcX=X.XoXoXoX",
"oXoX X,X(   O . . . . . . +   ` ZX) y.UXnXiXyXcXUXt.] qXiXxXkXzXCXpXcXmXjXlXzX=X.XoXoXoX",
"oXoX X,X/   o             o   $.R.^ HXcXE p k e.MXGX_ j.bXkXkXxX*.y B -XnXjXzX=X.XoXoXoX",
"oXoX X,X/   o             o   %.#.U.AXfXd x.$XfXjXZXR.! mXjXmX>Xb qX! ~ JXgXzX=X.XoXoXoX",
"oXoX X,X/   o             o   X.^ -XMXaXx P y x.BXvX>XJ zXlXlXhXVXNXa g.SXhXzX=X.XoXoXoX",
"oXoX X,X/   o             o   o.) #XMXfXOXLXK.9 cXMX%XL xXlXjXnXxXA ;.PXjXlXzX=X.XoXoXoX",
"oXoX X,X/   o             o   *.5.z.KXyXl 9.R E nXFXv.{ NXjXxXsXp & n.Q.cXkXzX=X.XoXoXoX",
"oXoX X,X(   o             o   X.;XV kXAX'./ =.qXVXjXS W.lXkXnX2X) O.U a.mXjXzX=X.XoXoXoX",
"oXoX X,X(   O . . . . . . O   ) GXf.I aXUXUXUXLXaXI k.yXyXxXkXcXHXDXJXZXkXlXzX=X.XoXoXoX",
"oXoX X<X!                     ( xXAXc.Z 9.U.U.0.Z c.GX,XsXcXzXzXjXjXhXkXxXzXcX=X.XoXoXoX",
"oXoXXX@XY.M.C.V.V.V.V.V.V.C.M.T.=X%X9X(.:.~ ~ :.).9X&X#X&X=X=X=X=X=X=X=X=X=X=XOXXXoXoXoX",
"oXoXoXXX$X=X*X=X=X=X=X=X=X*X=X$X.X.X}.@X,X<X<X,X@X}..XXX.X.X.X.X.X.X.X.X.X.X.XXXoXoXoXoX",
"oXoXoXoXXX.X.X.X.X.X.X.X.X.X.XXXoXoXOXXX.X X X.XXXOXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXOXOXXX X XXXOXOXXX|. X X X X X X|.XXOXOXXX X X.XoXOXoXoXoX",
"oXoXXX|.|.=X>X>X=X|.}.#X,X>X>X>X>X>X>X,X@X|.}.$X>X>X;XXX}.XXoXoX",
"oXXX&X9XqXC.;.:.C.0XwXT.&.>.:.:.:.:.>.&.R.8XyX!.4.*.d.>XrX%XXXoX",
"OX|.9XkX=.q.}.{.0.&.MXx.                h.UXf.&.T.XXb.} ;XtX{.OX",
"OX|.qX=.U.UX<X5XUXP.2.B.  @ o o o o @   G.S.5.HXCX1XSX7X] XX+XoX",
"XX=XC.9.UXA.W J D.UXu.'   .         X   i.;.lXMX3.= $XUXW.*.>X.X",
" X>X>./.CXaX.XN Q.KX{.M o           .   { k.ZXdX6XH +XVXeX| @XXX",
" X>X>./.AX2X<X] 0.UX[.M O           .   { k.CXgXVXG +XVXeX| @XXX",
"XX=XC.9.UXz.L J h.UXy.]   .         X   p.;.xXlXlXA |.UXE.*.>X.X",
"OX|.wX-.Y.UX,X1XUXP.4.B.  o         o   F.F.6.GXSXwXAX8X[ oX+XoX",
"OX|.6XsXO.w.*X&Xq.o.xXv.    . * = +     k.HXi.O.P.{.l._ %XeX}.OX",
"oXXX%X0XhXq.h g q.hX0X}.R.|.M.+.} i.[.!.|.5XuX^.r.5.l.>XtX%XXXoX",
"OX|.5XnX9.5.I.R.5.0.lX8XJXM.-.A.I.9.6.vXwXhXkXmXGXKXZXxXxX4X XOX",
"OX}.tX8.x.SXSXkXAXc.<.zXf.7.CXHXjXDXI.+.8XjXkXbXdX5XnXjXcX3X XOX",
"XX&XL.1.FXAXe.4 iXIX1.z.;.BXvXo.i rXUXi.k.VXvX3XJ G V.BXzX3X XOX",
" X>X1.W.KX:XR S eXAX[.v K.AXaX^.N 0XCX@X=.VXvX*X=XV.I GXlX3X XOX",
" X>X;.(.PXH 1.F oXDXOXf T.VXxXhXA qXVX=X*.VXdXFX6XI qXbXxX3X XOX",
".X-Xx.d.JX3.#.+ D.UXf.-.r.DXjXwXz 4XIXA.q.CXvX1X+ L R.zXxX3X XOX",
"oX X5X...XUXFX#XLXoX' uX:.U.UXcX.XSX9X' &XlXvX6XK.S.!.cXxX3X XOX",
"OX}.rXaX@.N.,X0XV.#.rXyXsXO.p.1XiXJ.) $XtXgXlXbXDXFXZXkXvX4X XOX",
"oX+X_.(.R.} H F } R.(.XX8XdXd.B l &.7XtX%X4X5X4X1X1X2X4X6X=XXXoX",
" X,X-.    * % % *     R.HXG.-.h.c.3.i.lX5XfXkXhXhXjXgXhXzX3X XOX",
" X>X:.  o         .   }.T.#.gXNXzXvXz.3.rXhXlXnXNXlXBXkXvX4X XOX",
" X>X:.  o       .     D.#.CXOXS } _.UX3.N.NXxXqX/ K !.MXzX3X XOX",
" X>X:.  o           & %.n.UXk.z c.tXCXXX-.VXnXOXT.N.K GXlX3X XOX",
" X>X:.  o           = } K.JX.XY.@.,.PX*X*.VXfXSXcXE $XMXzX3X XOX",
" X>X:.  o           @ 0.t.UXL.5.+.1.UXL.5.CXxX0X1 Y oXlXcX3X XOX",
" X>X>.  @ o o o o O   _.-. XFXx.c.SXkX] |.xXbX,Xr.y.Z.vXzX3X XOX",
"|.,X%.                /.sX[ G.lXbX{.} ).iXkXcXMXLXKXFXxXmX5X XOX",
"XX%XA.%.>.:.:.:.:.:.-._.tX-X1.[ { @.(.yX%X3X4X3X<X<X1X3X5X*X.XoX",
"oXXX%X,X>X>X>X>X>X>X,X+X{.oX>X#X+X:X#X{.XX X X X X X X X X.XoXoX",
"oXoXXX|. X X X X X X XoXOXoX.XXXoX.XXXOXoXOXOXOXOXOXOXOXOXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"OX X.X:X@X%X-X}.#X,X>X>X>X>X,X$X{.&X=X+X;X+X|.OX",
" X6XqXg.5.4.A.lXn.A U P P U A b.cX~.6.4.r.;X0X|.",
".XqXw._.aXaXb.J.t.            u.OXq.rXkX#X7.$X@X",
":Xg.`.pXO.8.SXM.^   + o o @   ,.i.ZX.XK cX7X1.&X",
"@X4.sXjXR.I jX2Xz   .     .   P W.ZX5X! :XDXe.^.",
"%X4.dX;Xm.F 7X,Xc   .     X   W I.VXMX_ *XDX7._.",
"-XD.V.kXe.H.vXs.O.  X     X   0.p.9XKXK.mX[.e.-X",
"|.iXz.n.rX2X8.}.p.  + % % $   t.9X:.R.:XB.q.7XXX",
".X1XxXt.b C P.vX].{.m.| ' p.].|.pX,Xm.d.G.tX4X X",
"|.aXv.v.qX6Xt.Y.MX'.i.2X0Xv.D.dXfXvXUXUXFXcXwX X",
"-XA.b.UXE.m.HX0.H.w.FX~.f.UXz.C.MXvXC.,.3XmXqX X",
"%X4.aXhXP | UX+XF =XDXN.L MXwX8.mXsX(.<.y.LX9X X",
"@X1.NX7.J ! vX>XB <XBXtX' cXyX0.cXnX-X| wXmXqX X",
":Xh.Q.yXv.#.GXj.u.v.IXwX6.UXU.j.BXvX` U ].BX0X X",
".XuXd.|.VXxXZ.V.cXx.v.fXvXE.q.0XlXzXbXkXgXbXeX X",
"oX{.Q.X.! Q 4.'.#XkXV.I H r.aX1X7X0X8X7X0XqX1X.X",
",XH   * X + $   '.2Xe.Q.(.p.~.iXsXhXnXZXjXlXqX X",
">XI   .         L.r.8X'.W.dXt.^.nXbXoXA.gXbXwX X",
">XP   o   .   % #.OXtXp e.bX4X8.NXgXl. .s.KX9X X",
">XP   o       % ' 5X9XC.%.'.zX9.cXzXzX2.&XVXqX X",
">XU   @ o o X & 3.T.cX3.' 8X&Xe.NXmX! m #XmX0X X",
",XS             (.f.[.wXuX9X4.-XbXxX7X;X9XBXeX X",
"*X2.S U P P I H {.rX0.e.i.1.%X8X9XeXiXsXyXeX2X.X",
"XX*X,X>X>X>X>X,XoXXX;X).~.*X@X|..X X|.}.|. X.XoX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"XXOX#X'.#X@X-X-X-X-XOX$X'.@X+XXX",
"OX1XH.K.U._.B V V M |.E.J.D.*X+X",
"#XJ.OXD.&X0.        y.>XI.=XS.XX",
"].A.bX} *Xa.  @ O @ <.UXq.4X!.W.",
"#XH.oXL.@X8.        e.2X;X$XS.oX",
"XX8Xb.r.C.+X{ V m ` $XT.U.G.=X+X",
"#X.XE._.H.%X X}.OX~.yXbX<XvXuX X",
".XC.yX=.yXq.}.|.V.-X).cXr.}.hX|.",
"{.F.].L 6Xq. XuXG.3X/.vX#.*XfX|.",
"$X.X}.4X/..XT.XX.XG.8XaX_.tXtX X",
"#Xe.m j n V.<X9.4.].iXpXBXjX6XXX",
";Xk       J '.I.+XU.:XzXK.0XaX X",
"-XS   $   z 9Xa.p.7XW.mX5.].hX}.",
";Xx       C  X`.P./.@XjX<.7XdX|.",
"&XO.x S k r. XC.P.U.wXtXiXyX6X.X",
"XX&X;X-X;X$X#X`./.$X.X X X.X.XoX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
